from . import DOMAIN as DOMAIN
from homeassistant.components.automation import AutomationActionType as AutomationActionType
from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA as DEVICE_TRIGGER_BASE_SCHEMA
from homeassistant.components.homeassistant.triggers.state import CONF_FOR as CONF_FOR, CONF_FROM as CONF_FROM, CONF_TO as CONF_TO
from homeassistant.components.select.const import ATTR_OPTIONS as ATTR_OPTIONS
from homeassistant.const import CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_PLATFORM as CONF_PLATFORM, CONF_TYPE as CONF_TYPE
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, HomeAssistant as HomeAssistant, HomeAssistantError as HomeAssistantError
from homeassistant.helpers import entity_registry as entity_registry
from homeassistant.helpers.entity import get_capability as get_capability
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

TRIGGER_TYPES: Any
TRIGGER_SCHEMA: Any

async def async_get_triggers(hass: HomeAssistant, device_id: str) -> list[dict]: ...
async def async_attach_trigger(hass: HomeAssistant, config: ConfigType, action: AutomationActionType, automation_info: dict) -> CALLBACK_TYPE: ...
async def async_get_trigger_capabilities(hass: HomeAssistant, config: ConfigType) -> dict[str, Any]: ...



import voluptuous as vol
from .const import CONF_BUFFER_SIZE as CONF_BUFFER_SIZE, CONF_VALUE_ON as CONF_VALUE_ON, DEFAULT_BUFFER_SIZE as DEFAULT_BUFFER_SIZE, DEFAULT_NAME as DEFAULT_NAME, DEFAULT_SSL as DEFAULT_SSL, DEFAULT_TIMEOUT as DEFAULT_TIMEOUT, DEFAULT_VERIFY_SSL as DEFAULT_VERIFY_SSL
from .model import TcpSensorConfig as TcpSensorConfig
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_NAME as CONF_NAME, CONF_PAYLOAD as CONF_PAYLOAD, CONF_PORT as CONF_PORT, CONF_SSL as CONF_SSL, CONF_TIMEOUT as CONF_TIMEOUT, CONF_UNIT_OF_MEASUREMENT as CONF_UNIT_OF_MEASUREMENT, CONF_VALUE_TEMPLATE as CONF_VALUE_TEMPLATE, CONF_VERIFY_SSL as CONF_VERIFY_SSL
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.exceptions import TemplateError as TemplateError
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.template import Template as Template
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any, Final

_LOGGER: Final[Any]
TCP_PLATFORM_SCHEMA: Final[dict[vol.Marker, Any]]

class TcpEntity(Entity):
    _hass: Any
    _config: Any
    _ssl_context: Any
    _state: Any
    def __init__(self, hass: HomeAssistant, config: ConfigType) -> None: ...
    @property
    def name(self) -> str: ...
    def update(self) -> None: ...



from .connection import ActiveConnection as ActiveConnection
from .error import Disconnect as Disconnect
from .http import WebSocketAdapter as WebSocketAdapter
from aiohttp.web import Request as Request
from collections.abc import Callable as Callable
from homeassistant.auth.models import RefreshToken as RefreshToken, User as User
from homeassistant.components.http.ban import process_success_login as process_success_login, process_wrong_login as process_wrong_login
from homeassistant.const import __version__ as __version__
from homeassistant.core import HomeAssistant as HomeAssistant
from typing import Any, Final

TYPE_AUTH: Final[str]
TYPE_AUTH_INVALID: Final[str]
TYPE_AUTH_OK: Final[str]
TYPE_AUTH_REQUIRED: Final[str]
AUTH_MESSAGE_SCHEMA: Final[Any]

def auth_ok_message() -> dict[str, str]: ...
def auth_required_message() -> dict[str, str]: ...
def auth_invalid_message(message: str) -> dict[str, str]: ...

class AuthPhase:
    _hass: Any
    _send_message: Any
    _logger: Any
    _request: Any
    def __init__(self, logger: WebSocketAdapter, hass: HomeAssistant, send_message: Callable[[Union[str, dict[str, Any]]], None], request: Request) -> None: ...
    async def async_handle(self, msg: dict[str, str]) -> ActiveConnection: ...
    async def _async_finish_auth(self, user: User, refresh_token: RefreshToken) -> ActiveConnection: ...



from .const import DOMAIN as DOMAIN
from .data import DEVICE_CONSUMPTION_SCHEMA as DEVICE_CONSUMPTION_SCHEMA, ENERGY_SOURCE_SCHEMA as ENERGY_SOURCE_SCHEMA, EnergyManager as EnergyManager, EnergyPreferencesUpdate as EnergyPreferencesUpdate, async_get_manager as async_get_manager
from homeassistant.components import websocket_api as websocket_api
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from typing import Any

EnergyWebSocketCommandHandler: Any
AsyncEnergyWebSocketCommandHandler: Any

def async_setup(hass: HomeAssistant) -> None: ...
def _ws_with_manager(func: Any) -> websocket_api.WebSocketCommandHandler: ...
def ws_get_prefs(hass: HomeAssistant, connection: websocket_api.ActiveConnection, msg: dict, manager: EnergyManager) -> None: ...
async def ws_save_prefs(hass: HomeAssistant, connection: websocket_api.ActiveConnection, msg: dict, manager: EnergyManager) -> None: ...
def ws_info(hass: HomeAssistant, connection: websocket_api.ActiveConnection, msg: dict) -> None: ...



from .const import CONF_FFMPEG_ARGUMENTS as CONF_FFMPEG_ARGUMENTS, DATA_COORDINATOR as DATA_COORDINATOR, DEFAULT_FFMPEG_ARGUMENTS as DEFAULT_FFMPEG_ARGUMENTS, DOMAIN as DOMAIN, MANUFACTURER as MANUFACTURER
from .coordinator import CanaryDataUpdateCoordinator as CanaryDataUpdateCoordinator
from aiohttp.web import Request as Request, StreamResponse as StreamResponse
from canary.api import Device as Device, Location as Location
from canary.live_stream_api import LiveStreamSession as LiveStreamSession
from homeassistant.components.camera import Camera as Camera
from homeassistant.components.ffmpeg import DATA_FFMPEG as DATA_FFMPEG, FFmpegManager as FFmpegManager
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.aiohttp_client import async_aiohttp_proxy_stream as async_aiohttp_proxy_stream
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity
from homeassistant.util import Throttle as Throttle
from typing import Any, Final

MIN_TIME_BETWEEN_SESSION_RENEW: Final[Any]
PLATFORM_SCHEMA: Final[Any]

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class CanaryCamera(CoordinatorEntity, Camera):
    coordinator: CanaryDataUpdateCoordinator
    _ffmpeg: Any
    _ffmpeg_arguments: Any
    _location_id: Any
    _device: Any
    _live_stream_session: Any
    _attr_name: Any
    _attr_unique_id: Any
    _attr_device_info: Any
    def __init__(self, hass: HomeAssistant, coordinator: CanaryDataUpdateCoordinator, location_id: str, device: Device, ffmpeg_args: str) -> None: ...
    @property
    def location(self) -> Location: ...
    @property
    def is_recording(self) -> bool: ...
    @property
    def motion_detection_enabled(self) -> bool: ...
    async def async_camera_image(self) -> Union[bytes, None]: ...
    async def handle_async_mjpeg_stream(self, request: Request) -> Union[StreamResponse, None]: ...
    def renew_live_stream_session(self) -> None: ...



from .const import DOMAIN as DOMAIN
from .utils import BondHub as BondHub
from homeassistant import config_entries as config_entries, exceptions as exceptions
from homeassistant.const import CONF_ACCESS_TOKEN as CONF_ACCESS_TOKEN, CONF_HOST as CONF_HOST, CONF_NAME as CONF_NAME, HTTP_UNAUTHORIZED as HTTP_UNAUTHORIZED
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from homeassistant.helpers.typing import DiscoveryInfoType as DiscoveryInfoType
from typing import Any

_LOGGER: Any
USER_SCHEMA: Any
DISCOVERY_SCHEMA: Any
TOKEN_SCHEMA: Any

async def _validate_input(hass: HomeAssistant, data: dict[str, Any]) -> tuple[str, str]: ...

class ConfigFlow(config_entries.ConfigFlow):
    VERSION: int
    _discovered: Any
    def __init__(self) -> None: ...
    async def _async_try_automatic_configure(self) -> None: ...
    async def async_step_zeroconf(self, discovery_info: DiscoveryInfoType) -> FlowResult: ...
    async def async_step_confirm(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...

class InputValidationError(exceptions.HomeAssistantError):
    base: Any
    def __init__(self, base: str) -> None: ...



from collections.abc import Iterable
from homeassistant.const import ATTR_LATITUDE as ATTR_LATITUDE, ATTR_LONGITUDE as ATTR_LONGITUDE
from homeassistant.core import HomeAssistant as HomeAssistant, State as State
from typing import Any

_LOGGER: Any

def has_location(state: State) -> bool: ...
def closest(latitude: float, longitude: float, states: Iterable[State]) -> Union[State, None]: ...
def find_coordinates(hass: HomeAssistant, entity_id: str, recursion_history: Union[list, None] = ...) -> Union[str, None]: ...
def _get_location_from_attributes(entity_state: State) -> str: ...



from . import GroupEntity as GroupEntity
from collections.abc import Iterator
from homeassistant.components import light as light
from homeassistant.components.light import ATTR_BRIGHTNESS as ATTR_BRIGHTNESS, ATTR_COLOR_MODE as ATTR_COLOR_MODE, ATTR_COLOR_TEMP as ATTR_COLOR_TEMP, ATTR_EFFECT as ATTR_EFFECT, ATTR_EFFECT_LIST as ATTR_EFFECT_LIST, ATTR_FLASH as ATTR_FLASH, ATTR_HS_COLOR as ATTR_HS_COLOR, ATTR_MAX_MIREDS as ATTR_MAX_MIREDS, ATTR_MIN_MIREDS as ATTR_MIN_MIREDS, ATTR_RGBWW_COLOR as ATTR_RGBWW_COLOR, ATTR_RGBW_COLOR as ATTR_RGBW_COLOR, ATTR_RGB_COLOR as ATTR_RGB_COLOR, ATTR_SUPPORTED_COLOR_MODES as ATTR_SUPPORTED_COLOR_MODES, ATTR_TRANSITION as ATTR_TRANSITION, ATTR_WHITE_VALUE as ATTR_WHITE_VALUE, ATTR_XY_COLOR as ATTR_XY_COLOR, COLOR_MODE_BRIGHTNESS as COLOR_MODE_BRIGHTNESS, COLOR_MODE_ONOFF as COLOR_MODE_ONOFF, PLATFORM_SCHEMA as PLATFORM_SCHEMA, SUPPORT_EFFECT as SUPPORT_EFFECT, SUPPORT_FLASH as SUPPORT_FLASH, SUPPORT_TRANSITION as SUPPORT_TRANSITION, SUPPORT_WHITE_VALUE as SUPPORT_WHITE_VALUE
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, ATTR_SUPPORTED_FEATURES as ATTR_SUPPORTED_FEATURES, CONF_ENTITIES as CONF_ENTITIES, CONF_NAME as CONF_NAME, CONF_UNIQUE_ID as CONF_UNIQUE_ID, STATE_ON as STATE_ON, STATE_UNAVAILABLE as STATE_UNAVAILABLE
from homeassistant.core import CoreState as CoreState, Event as Event, HomeAssistant as HomeAssistant, State as State
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.event import async_track_state_change_event as async_track_state_change_event
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any, Callable

DEFAULT_NAME: str
SUPPORT_GROUP_LIGHT: Any

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[dict[str, Any], None] = ...) -> None: ...

class LightGroup(GroupEntity, light.LightEntity):
    _attr_available: bool
    _attr_icon: str
    _attr_is_on: bool
    _attr_max_mireds: int
    _attr_min_mireds: int
    _attr_should_poll: bool
    _entity_ids: Any
    _white_value: Any
    _attr_name: Any
    _attr_extra_state_attributes: Any
    _attr_unique_id: Any
    def __init__(self, unique_id: Union[str, None], name: str, entity_ids: list[str]) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    @property
    def white_value(self) -> Union[int, None]: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    _attr_brightness: Any
    _attr_hs_color: Any
    _attr_rgb_color: Any
    _attr_rgbw_color: Any
    _attr_rgbww_color: Any
    _attr_xy_color: Any
    _attr_color_temp: Any
    _attr_effect_list: Any
    _attr_effect: Any
    _attr_color_mode: Any
    _attr_supported_color_modes: Any
    _attr_supported_features: int
    async def async_update(self) -> None: ...

def _find_state_attributes(states: list[State], key: str) -> Iterator[Any]: ...
def _mean_int(*args: Any) -> int: ...
def _mean_tuple(*args: Any) -> tuple[Union[float, Any], ...]: ...
def _reduce_attribute(states: list[State], key: str, default: Union[Any, None] = ..., reduce: Callable[..., Any] = ...) -> Any: ...



from . import ShellyDeviceWrapper as ShellyDeviceWrapper
from .const import COAP as COAP, DATA_CONFIG_ENTRY as DATA_CONFIG_ENTRY, DOMAIN as DOMAIN
from .entity import ShellyBlockEntity as ShellyBlockEntity
from .utils import async_remove_shelly_entity as async_remove_shelly_entity
from aioshelly import Block as Block
from homeassistant.components.switch import SwitchEntity as SwitchEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class RelaySwitch(ShellyBlockEntity, SwitchEntity):
    control_result: Any
    def __init__(self, wrapper: ShellyDeviceWrapper, block: Block) -> None: ...
    @property
    def is_on(self) -> bool: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    def _update_callback(self) -> None: ...



from .const import ATTR_CONFIGURED_ADAPTERS as ATTR_CONFIGURED_ADAPTERS, DEFAULT_CONFIGURED_ADAPTERS as DEFAULT_CONFIGURED_ADAPTERS, STORAGE_KEY as STORAGE_KEY, STORAGE_VERSION as STORAGE_VERSION
from .models import Adapter as Adapter
from .util import adapters_with_exernal_addresses as adapters_with_exernal_addresses, async_load_adapters as async_load_adapters, enable_adapters as enable_adapters, enable_auto_detected_adapters as enable_auto_detected_adapters
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from typing import Any

class Network:
    _store: Any
    _data: Any
    adapters: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    @property
    def configured_adapters(self) -> list[str]: ...
    async def async_setup(self) -> None: ...
    async def async_migrate_from_zeroconf(self, zc_config: dict[str, Any]) -> None: ...
    def async_configure(self) -> None: ...
    async def async_reconfig(self, config: dict[str, Any]) -> None: ...
    async def async_load(self) -> None: ...
    async def _async_save(self) -> None: ...



from .const import CONF_CONNECTIONS as CONF_CONNECTIONS, CONF_COORDINATOR as CONF_COORDINATOR, DOMAIN as DOMAIN, LOGGER as LOGGER, PLATFORMS as PLATFORMS
from .model import EntityInfo as EntityInfo
from homeassistant.components.sensor import ATTR_STATE_CLASS as ATTR_STATE_CLASS
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_DEVICE_CLASS as ATTR_DEVICE_CLASS, ATTR_ENTITY_ID as ATTR_ENTITY_ID, ATTR_NAME as ATTR_NAME, ATTR_UNIT_OF_MEASUREMENT as ATTR_UNIT_OF_MEASUREMENT, CONF_HOST as CONF_HOST, CONF_PASSWORD as CONF_PASSWORD, CONF_USERNAME as CONF_USERNAME, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant
from homeassistant.exceptions import ConfigEntryAuthFailed as ConfigEntryAuthFailed
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_registry import RegistryEntry as RegistryEntry, async_migrate_entries as async_migrate_entries
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity, DataUpdateCoordinator as DataUpdateCoordinator
from pyfritzhome import FritzhomeDevice as FritzhomeDevice
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class FritzBoxEntity(CoordinatorEntity):
    ain: Any
    _name: Any
    _unique_id: Any
    _unit_of_measurement: Any
    _device_class: Any
    _attr_state_class: Any
    def __init__(self, entity_info: EntityInfo, coordinator: DataUpdateCoordinator[dict[str, FritzhomeDevice]], ain: str) -> None: ...
    @property
    def available(self) -> bool: ...
    @property
    def device(self) -> FritzhomeDevice: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def name(self) -> str: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...
    @property
    def device_class(self) -> Union[str, None]: ...



from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, ATTR_NAME as ATTR_NAME, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_NAME as CONF_NAME, CONF_SOURCE as CONF_SOURCE
from homeassistant.core import callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers.config_validation import make_entity_service_schema as make_entity_service_schema
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.util.async_ import run_callback_threadsafe as run_callback_threadsafe
from typing import Any

_LOGGER: Any
DOMAIN: str
SCAN_INTERVAL: Any
DEVICE_CLASSES: Any
SERVICE_SCAN: str
EVENT_DETECT_FACE: str
ATTR_AGE: str
ATTR_CONFIDENCE: str
ATTR_FACES: str
ATTR_GENDER: str
ATTR_GLASSES: str
ATTR_MOTION: str
ATTR_TOTAL_FACES: str
CONF_CONFIDENCE: str
DEFAULT_TIMEOUT: int
DEFAULT_CONFIDENCE: int
SOURCE_SCHEMA: Any
PLATFORM_SCHEMA: Any
PLATFORM_SCHEMA_BASE: Any

async def async_setup(hass, config): ...

class ImageProcessingEntity(Entity):
    timeout: Any
    @property
    def camera_entity(self) -> None: ...
    @property
    def confidence(self) -> None: ...
    def process_image(self, image) -> None: ...
    async def async_process_image(self, image): ...
    async def async_update(self) -> None: ...

class ImageProcessingFaceEntity(ImageProcessingEntity):
    faces: Any
    total_faces: int
    def __init__(self) -> None: ...
    @property
    def state(self): ...
    @property
    def device_class(self): ...
    @property
    def state_attributes(self): ...
    def process_faces(self, faces, total) -> None: ...
    def async_process_faces(self, faces, total) -> None: ...



from aiohttp import web as web
from homeassistant import config_entries as config_entries, data_entry_flow as data_entry_flow
from homeassistant.components.http import HomeAssistantView as HomeAssistantView
from homeassistant.components.http.data_validator import RequestDataValidator as RequestDataValidator
from homeassistant.const import HTTP_BAD_REQUEST as HTTP_BAD_REQUEST, HTTP_NOT_FOUND as HTTP_NOT_FOUND
from typing import Any

class _BaseFlowManagerView(HomeAssistantView):
    _flow_mgr: Any
    def __init__(self, flow_mgr: data_entry_flow.FlowManager) -> None: ...
    def _prepare_result_json(self, result: data_entry_flow.FlowResult) -> data_entry_flow.FlowResult: ...

class FlowManagerIndexView(_BaseFlowManagerView):
    async def post(self, request: web.Request, data: dict[str, Any]) -> web.Response: ...

class FlowManagerResourceView(_BaseFlowManagerView):
    async def get(self, request: web.Request, flow_id: str) -> web.Response: ...
    async def post(self, request: web.Request, flow_id: str, data: dict[str, Any]) -> web.Response: ...
    async def delete(self, request: web.Request, flow_id: str) -> web.Response: ...



from typing import Any

API: str
DOMAIN: str
MANUFACTURER: str
DEFAULT_ATTRIBUTION: Any
PLATFORMS: Any
MODEL_NAPLUG: str
MODEL_NATHERM1: str
MODEL_NRV: str
MODEL_NOC: str
MODEL_NACAMERA: str
MODEL_NSD: str
MODEL_NACAMDOORTAG: str
MODEL_NHC: str
MODEL_NAMAIN: str
MODEL_NAMODULE1: str
MODEL_NAMODULE4: str
MODEL_NAMODULE3: str
MODEL_NAMODULE2: str
MODEL_PUBLIC: str
MODELS: Any
AUTH: str
CONF_PUBLIC: str
CAMERA_DATA: str
HOME_DATA: str
DATA_HANDLER: str
SIGNAL_NAME: str
CONF_CLOUDHOOK_URL: str
CONF_WEATHER_AREAS: str
CONF_NEW_AREA: str
CONF_AREA_NAME: str
CONF_LAT_NE: str
CONF_LON_NE: str
CONF_LAT_SW: str
CONF_LON_SW: str
CONF_PUBLIC_MODE: str
CONF_UUID: str
OAUTH2_AUTHORIZE: str
OAUTH2_TOKEN: str
DATA_CAMERAS: str
DATA_DEVICE_IDS: str
DATA_EVENTS: str
DATA_HOMES: str
DATA_PERSONS: str
DATA_SCHEDULES: str
NETATMO_WEBHOOK_URL: Any
NETATMO_EVENT: str
DEFAULT_PERSON: str
DEFAULT_DISCOVERY: bool
DEFAULT_WEBHOOKS: bool
ATTR_PSEUDO: str
ATTR_EVENT_TYPE: str
ATTR_HEATING_POWER_REQUEST: str
ATTR_HOME_ID: str
ATTR_HOME_NAME: str
ATTR_PERSON: str
ATTR_PERSONS: str
ATTR_IS_KNOWN: str
ATTR_FACE_URL: str
ATTR_SCHEDULE_ID: str
ATTR_SCHEDULE_NAME: str
ATTR_SELECTED_SCHEDULE: str
ATTR_CAMERA_LIGHT_MODE: str
SERVICE_SET_CAMERA_LIGHT: str
SERVICE_SET_SCHEDULE: str
SERVICE_SET_PERSONS_HOME: str
SERVICE_SET_PERSON_AWAY: str
EVENT_TYPE_SET_POINT: str
EVENT_TYPE_CANCEL_SET_POINT: str
EVENT_TYPE_THERM_MODE: str
EVENT_TYPE_SCHEDULE: str
EVENT_TYPE_LIGHT_MODE: str
EVENT_TYPE_CAMERA_OUTDOOR: str
EVENT_TYPE_CAMERA_ANIMAL: str
EVENT_TYPE_CAMERA_HUMAN: str
EVENT_TYPE_CAMERA_VEHICLE: str
EVENT_TYPE_CAMERA_MOVEMENT: str
EVENT_TYPE_CAMERA_PERSON: str
EVENT_TYPE_CAMERA_PERSON_AWAY: str
EVENT_TYPE_DOOR_TAG_SMALL_MOVE: str
EVENT_TYPE_DOOR_TAG_BIG_MOVE: str
EVENT_TYPE_DOOR_TAG_OPEN: str
EVENT_TYPE_OFF: str
EVENT_TYPE_ON: str
EVENT_TYPE_ALARM_STARTED: str
OUTDOOR_CAMERA_TRIGGERS: Any
INDOOR_CAMERA_TRIGGERS: Any
DOOR_TAG_TRIGGERS: Any
CLIMATE_TRIGGERS: Any
EVENT_ID_MAP: Any
MODE_LIGHT_ON: str
MODE_LIGHT_OFF: str
MODE_LIGHT_AUTO: str
CAMERA_LIGHT_MODES: Any
WEBHOOK_ACTIVATION: str
WEBHOOK_DEACTIVATION: str
WEBHOOK_NACAMERA_CONNECTION: str
WEBHOOK_PUSH_TYPE: str
WEBHOOK_LIGHT_MODE: str



from .const import DATA_CONNECTIONS as DATA_CONNECTIONS, SIGNAL_WEBSOCKET_CONNECTED as SIGNAL_WEBSOCKET_CONNECTED, SIGNAL_WEBSOCKET_DISCONNECTED as SIGNAL_WEBSOCKET_DISCONNECTED
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[dict[str, Any], None] = ...) -> None: ...

class APICount(SensorEntity):
    count: int
    def __init__(self) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def state(self) -> int: ...
    @property
    def unit_of_measurement(self) -> str: ...
    def _update_count(self) -> None: ...



from .const import CONF_KAMEREON_ACCOUNT_ID as CONF_KAMEREON_ACCOUNT_ID, DEFAULT_SCAN_INTERVAL as DEFAULT_SCAN_INTERVAL
from .renault_vehicle import RenaultVehicleProxy as RenaultVehicleProxy
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from renault_api.renault_account import RenaultAccount as RenaultAccount
from typing import Any

LOGGER: Any

class RenaultHub:
    _hass: Any
    _client: Any
    _account: Any
    _vehicles: Any
    def __init__(self, hass: HomeAssistant, locale: str) -> None: ...
    async def attempt_login(self, username: str, password: str) -> bool: ...
    async def async_initialise(self, config_entry: ConfigEntry) -> None: ...
    async def get_account_ids(self) -> list[str]: ...
    @property
    def vehicles(self) -> dict[str, RenaultVehicleProxy]: ...



from .const import CONF_TRACKED_ASSET_PAIRS as CONF_TRACKED_ASSET_PAIRS, DEFAULT_SCAN_INTERVAL as DEFAULT_SCAN_INTERVAL, DOMAIN as DOMAIN
from .utils import get_tradable_asset_pairs as get_tradable_asset_pairs
from homeassistant import config_entries as config_entries
from homeassistant.const import CONF_SCAN_INTERVAL as CONF_SCAN_INTERVAL
from homeassistant.core import callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from typing import Any

_LOGGER: Any

class KrakenConfigFlow(config_entries.ConfigFlow):
    VERSION: int
    @staticmethod
    def async_get_options_flow(config_entry: config_entries.ConfigEntry) -> KrakenOptionsFlowHandler: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...

class KrakenOptionsFlowHandler(config_entries.OptionsFlow):
    config_entry: Any
    def __init__(self, config_entry: config_entries.ConfigEntry) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



from . import permissions as perm_mdl
from .const import GROUP_ID_ADMIN as GROUP_ID_ADMIN
from datetime import datetime, timedelta
from homeassistant.const import __version__ as __version__
from typing import NamedTuple

TOKEN_TYPE_NORMAL: str
TOKEN_TYPE_SYSTEM: str
TOKEN_TYPE_LONG_LIVED_ACCESS_TOKEN: str

class Group:
    name: Union[str, None]
    policy: perm_mdl.PolicyType
    id: str
    system_generated: bool
    def __init__(self, name, policy, id, system_generated) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class User:
    name: Union[str, None]
    perm_lookup: perm_mdl.PermissionLookup
    id: str
    is_owner: bool
    is_active: bool
    system_generated: bool
    groups: list[Group]
    credentials: list[Credentials]
    refresh_tokens: dict[str, RefreshToken]
    _permissions: Union[perm_mdl.PolicyPermissions, None]
    @property
    def permissions(self) -> perm_mdl.AbstractPermissions: ...
    @property
    def is_admin(self) -> bool: ...
    def invalidate_permission_cache(self) -> None: ...
    def __init__(self, name, perm_lookup, id, is_owner, is_active, system_generated, groups, credentials, refresh_tokens, permissions) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class RefreshToken:
    user: User
    client_id: Union[str, None]
    access_token_expiration: timedelta
    client_name: Union[str, None]
    client_icon: Union[str, None]
    token_type: str
    id: str
    created_at: datetime
    token: str
    jwt_key: str
    last_used_at: Union[datetime, None]
    last_used_ip: Union[str, None]
    credential: Union[Credentials, None]
    version: Union[str, None]
    def __init__(self, user, client_id, access_token_expiration, client_name, client_icon, token_type, id, created_at, token, jwt_key, last_used_at, last_used_ip, credential, version) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class Credentials:
    auth_provider_type: str
    auth_provider_id: Union[str, None]
    data: dict
    id: str
    is_new: bool
    def __init__(self, auth_provider_type, auth_provider_id, data, id, is_new) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class UserMeta(NamedTuple):
    name: Union[str, None]
    is_active: bool



from aiohttp import web
from homeassistant.components import http as http
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import HTTP_BAD_REQUEST as HTTP_BAD_REQUEST, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE, time_period_str as time_period_str
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.helpers.template import DATE_STR_FORMAT as DATE_STR_FORMAT
from homeassistant.util import dt as dt
from typing import Any

_LOGGER: Any
DOMAIN: str
ENTITY_ID_FORMAT: Any
SCAN_INTERVAL: Any

async def async_setup(hass, config): ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
def get_date(date): ...
def normalize_event(event): ...
def calculate_offset(event, offset): ...
def is_offset_reached(event): ...

class CalendarEventDevice(Entity):
    @property
    def event(self) -> None: ...
    @property
    def state_attributes(self): ...
    @property
    def state(self): ...
    async def async_get_events(self, hass, start_date, end_date) -> None: ...

class CalendarEventView(http.HomeAssistantView):
    url: str
    name: str
    component: Any
    def __init__(self, component: EntityComponent) -> None: ...
    async def get(self, request, entity_id): ...

class CalendarListView(http.HomeAssistantView):
    url: str
    name: str
    component: Any
    def __init__(self, component: EntityComponent) -> None: ...
    async def get(self, request: web.Request) -> web.Response: ...



from .const import CONF_KAMEREON_ACCOUNT_ID as CONF_KAMEREON_ACCOUNT_ID, CONF_LOCALE as CONF_LOCALE, DOMAIN as DOMAIN
from .renault_hub import RenaultHub as RenaultHub
from homeassistant import config_entries as config_entries
from homeassistant.const import CONF_PASSWORD as CONF_PASSWORD, CONF_USERNAME as CONF_USERNAME
from homeassistant.data_entry_flow import FlowResult as FlowResult
from typing import Any

class RenaultFlowHandler(config_entries.ConfigFlow):
    VERSION: int
    renault_config: Any
    renault_hub: Any
    def __init__(self) -> None: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    def _show_user_form(self, errors: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_kamereon(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



from .descriptions import DescriptionManager as DescriptionManager
from .flow import FlowDispatcher as FlowDispatcher, SSDPFlow as SSDPFlow
from async_upnp_client.utils import CaseInsensitiveDict
from collections.abc import Mapping
from homeassistant import config_entries as config_entries
from homeassistant.components import network as network
from homeassistant.const import EVENT_HOMEASSISTANT_STARTED as EVENT_HOMEASSISTANT_STARTED, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP, MATCH_ALL as MATCH_ALL
from homeassistant.core import CoreState as CoreState, HomeAssistant as HomeAssistant
from homeassistant.helpers.event import async_track_time_interval as async_track_time_interval
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.loader import async_get_ssdp as async_get_ssdp, bind_hass as bind_hass
from ipaddress import IPv4Address, IPv6Address
from typing import Any, Callable

DOMAIN: str
SCAN_INTERVAL: Any
IPV4_BROADCAST: Any
ATTR_SSDP_LOCATION: str
ATTR_SSDP_ST: str
ATTR_SSDP_USN: str
ATTR_SSDP_EXT: str
ATTR_SSDP_SERVER: str
ATTR_UPNP_DEVICE_TYPE: str
ATTR_UPNP_FRIENDLY_NAME: str
ATTR_UPNP_MANUFACTURER: str
ATTR_UPNP_MANUFACTURER_URL: str
ATTR_UPNP_MODEL_DESCRIPTION: str
ATTR_UPNP_MODEL_NAME: str
ATTR_UPNP_MODEL_NUMBER: str
ATTR_UPNP_MODEL_URL: str
ATTR_UPNP_SERIAL: str
ATTR_UPNP_UDN: str
ATTR_UPNP_UPC: str
ATTR_UPNP_PRESENTATION_URL: str
DISCOVERY_MAPPING: Any
_LOGGER: Any

def async_register_callback(hass: HomeAssistant, callback: Callable[[dict], None], match_dict: Union[None, dict[str, str]] = ...) -> Callable[[], None]: ...
def async_get_discovery_info_by_udn_st(hass: HomeAssistant, udn: str, st: str) -> Union[dict[str, str], None]: ...
def async_get_discovery_info_by_st(hass: HomeAssistant, st: str) -> list[dict[str, str]]: ...
def async_get_discovery_info_by_udn(hass: HomeAssistant, udn: str) -> list[dict[str, str]]: ...
async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
def _async_use_default_interface(adapters: list[network.Adapter]) -> bool: ...
def _async_process_callbacks(callbacks: list[Callable[[dict], None]], discovery_info: dict[str, str]) -> None: ...
def _async_headers_match(headers: Mapping[str, str], match_dict: dict[str, str]) -> bool: ...

class Scanner:
    hass: Any
    seen: Any
    cache: Any
    _integration_matchers: Any
    _cancel_scan: Any
    _ssdp_listeners: Any
    _callbacks: Any
    flow_dispatcher: Any
    description_manager: Any
    def __init__(self, hass: HomeAssistant, integration_matchers: dict[str, list[dict[str, str]]]) -> None: ...
    def async_register_callback(self, callback: Callable[[dict], None], match_dict: Union[None, dict[str, str]] = ...) -> Callable[[], None]: ...
    def async_stop(self, *_: Any) -> None: ...
    async def _async_build_source_set(self) -> set[Union[IPv4Address, IPv6Address]]: ...
    def async_scan(self, *_: Any) -> None: ...
    async def async_start(self) -> None: ...
    def _async_get_matching_callbacks(self, headers: Mapping[str, str]) -> list[Callable[[dict], None]]: ...
    def _async_matching_domains(self, info_with_req: CaseInsensitiveDict) -> set[str]: ...
    def _async_seen(self, header_st: Union[str, None], header_location: Union[str, None]) -> bool: ...
    def _async_see(self, header_st: Union[str, None], header_location: Union[str, None]) -> None: ...
    async def _async_process_entry(self, headers: Mapping[str, str]) -> None: ...
    def _async_headers_to_discovery_info(self, headers: Mapping[str, str]) -> dict[str, str]: ...
    def async_get_discovery_info_by_udn_st(self, udn: str, st: str) -> Union[dict[str, str], None]: ...
    def async_get_discovery_info_by_st(self, st: str) -> list[dict[str, str]]: ...
    def async_get_discovery_info_by_udn(self, udn: str) -> list[dict[str, str]]: ...

def discovery_info_from_headers_and_request(info_with_req: CaseInsensitiveDict) -> dict[str, str]: ...
def _udn_from_usn(usn: Union[str, None]) -> Union[str, None]: ...



from .const import DEVICE_ID as DEVICE_ID, DOMAIN as DOMAIN, EVENT_TAG_SCANNED as EVENT_TAG_SCANNED, TAG_ID as TAG_ID
from homeassistant.components.automation import AutomationActionType as AutomationActionType
from homeassistant.const import CONF_PLATFORM as CONF_PLATFORM
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, Event as Event, HassJob as HassJob, HomeAssistant as HomeAssistant
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

TRIGGER_SCHEMA: Any

async def async_attach_trigger(hass: HomeAssistant, config: ConfigType, action: AutomationActionType, automation_info: dict) -> CALLBACK_TYPE: ...



from .const import DEFAULT_SCAN_INTERVAL as DEFAULT_SCAN_INTERVAL, DOMAIN as DOMAIN
from homeassistant import config_entries as config_entries
from homeassistant.const import CONF_PASSWORD as CONF_PASSWORD, CONF_SCAN_INTERVAL as CONF_SCAN_INTERVAL, CONF_USERNAME as CONF_USERNAME
from homeassistant.core import callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from typing import Any

_LOGGER: Any

class UpCloudConfigFlow(config_entries.ConfigFlow):
    VERSION: int
    username: str
    password: str
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_import(self, user_input: dict[str, Any]) -> FlowResult: ...
    def _async_show_form(self, step_id: str, user_input: Union[dict[str, Any], None] = ..., errors: Union[dict[str, str], None] = ...) -> FlowResult: ...
    @staticmethod
    def async_get_options_flow(config_entry: config_entries.ConfigEntry) -> UpCloudOptionsFlow: ...

class UpCloudOptionsFlow(config_entries.OptionsFlow):
    config_entry: Any
    def __init__(self, config_entry: config_entries.ConfigEntry) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



from . import singleton as singleton, storage as storage
from homeassistant.core import HomeAssistant as HomeAssistant

DATA_KEY: str
DATA_VERSION: int
LEGACY_UUID_FILE: str

async def async_get(hass: HomeAssistant) -> str: ...



from .const import CONF_CITY as CONF_CITY, CONF_COUNTRY as CONF_COUNTRY, CONF_GEOGRAPHIES as CONF_GEOGRAPHIES, CONF_INTEGRATION_TYPE as CONF_INTEGRATION_TYPE, DATA_COORDINATOR as DATA_COORDINATOR, DOMAIN as DOMAIN, INTEGRATION_TYPE_GEOGRAPHY_COORDS as INTEGRATION_TYPE_GEOGRAPHY_COORDS, INTEGRATION_TYPE_GEOGRAPHY_NAME as INTEGRATION_TYPE_GEOGRAPHY_NAME, INTEGRATION_TYPE_NODE_PRO as INTEGRATION_TYPE_NODE_PRO, LOGGER as LOGGER
from collections.abc import Mapping
from datetime import timedelta
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION, CONF_API_KEY as CONF_API_KEY, CONF_IP_ADDRESS as CONF_IP_ADDRESS, CONF_LATITUDE as CONF_LATITUDE, CONF_LONGITUDE as CONF_LONGITUDE, CONF_PASSWORD as CONF_PASSWORD, CONF_SHOW_ON_MAP as CONF_SHOW_ON_MAP, CONF_STATE as CONF_STATE
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import ConfigEntryAuthFailed as ConfigEntryAuthFailed
from homeassistant.helpers import aiohttp_client as aiohttp_client, entity_registry as entity_registry
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity, DataUpdateCoordinator as DataUpdateCoordinator, UpdateFailed as UpdateFailed
from typing import Any

PLATFORMS: Any
DATA_LISTENER: str
DEFAULT_ATTRIBUTION: str
DEFAULT_NODE_PRO_UPDATE_INTERVAL: Any
CONFIG_SCHEMA: Any

def async_get_geography_id(geography_dict: Mapping[str, Any]) -> str: ...
def async_get_cloud_api_update_interval(hass: HomeAssistant, api_key: str, num_consumers: int) -> timedelta: ...
def async_get_cloud_coordinators_by_api_key(hass: HomeAssistant, api_key: str) -> list[DataUpdateCoordinator]: ...
def async_sync_geo_coordinator_update_intervals(hass: HomeAssistant, api_key: str) -> None: ...
def _standardize_geography_config_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> None: ...
def _standardize_node_pro_config_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> None: ...
async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> bool: ...
async def async_migrate_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> bool: ...
async def async_reload_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> None: ...

class AirVisualEntity(CoordinatorEntity):
    _attr_extra_state_attributes: Any
    def __init__(self, coordinator: DataUpdateCoordinator) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    def update_from_latest_data(self) -> None: ...



import voluptuous as vol
from .view import HomeAssistantView as HomeAssistantView
from aiohttp import web as web
from collections.abc import Awaitable
from homeassistant.const import HTTP_BAD_REQUEST as HTTP_BAD_REQUEST
from typing import Any, Callable

_LOGGER: Any

class RequestDataValidator:
    _schema: Any
    _allow_empty: Any
    def __init__(self, schema: vol.Schema, allow_empty: bool = ...) -> None: ...
    def __call__(self, method: Callable[..., Awaitable[web.StreamResponse]]) -> Callable: ...



import pyatmo
from .const import CONF_WEATHER_AREAS as CONF_WEATHER_AREAS, DATA_HANDLER as DATA_HANDLER, DOMAIN as DOMAIN, MANUFACTURER as MANUFACTURER, SIGNAL_NAME as SIGNAL_NAME
from .data_handler import HOMECOACH_DATA_CLASS_NAME as HOMECOACH_DATA_CLASS_NAME, NetatmoDataHandler as NetatmoDataHandler, PUBLICDATA_DATA_CLASS_NAME as PUBLICDATA_DATA_CLASS_NAME, WEATHERSTATION_DATA_CLASS_NAME as WEATHERSTATION_DATA_CLASS_NAME
from .helper import NetatmoArea as NetatmoArea
from .netatmo_entity_base import NetatmoBase as NetatmoBase
from homeassistant.components.sensor import SensorEntity as SensorEntity, SensorEntityDescription as SensorEntityDescription
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_LATITUDE as ATTR_LATITUDE, ATTR_LONGITUDE as ATTR_LONGITUDE, CONCENTRATION_PARTS_PER_MILLION as CONCENTRATION_PARTS_PER_MILLION, DEGREE as DEGREE, DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_CO2 as DEVICE_CLASS_CO2, DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_PRESSURE as DEVICE_CLASS_PRESSURE, DEVICE_CLASS_SIGNAL_STRENGTH as DEVICE_CLASS_SIGNAL_STRENGTH, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, LENGTH_MILLIMETERS as LENGTH_MILLIMETERS, PERCENTAGE as PERCENTAGE, PRESSURE_MBAR as PRESSURE_MBAR, SIGNAL_STRENGTH_DECIBELS_MILLIWATT as SIGNAL_STRENGTH_DECIBELS_MILLIWATT, SOUND_PRESSURE_DB as SOUND_PRESSURE_DB, SPEED_KILOMETERS_PER_HOUR as SPEED_KILOMETERS_PER_HOUR, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import PlatformNotReady as PlatformNotReady
from homeassistant.helpers.device_registry import async_entries_for_config_entry as async_entries_for_config_entry
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect, async_dispatcher_send as async_dispatcher_send
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any, NamedTuple

_LOGGER: Any
SUPPORTED_PUBLIC_SENSOR_TYPES: tuple[str, ...]

class NetatmoRequiredKeysMixin:
    netatmo_name: str

class NetatmoSensorEntityDescription(SensorEntityDescription, NetatmoRequiredKeysMixin): ...

SENSOR_TYPES: tuple[NetatmoSensorEntityDescription, ...]
SENSOR_TYPES_KEYS: Any
MODULE_TYPE_OUTDOOR: str
MODULE_TYPE_WIND: str
MODULE_TYPE_RAIN: str
MODULE_TYPE_INDOOR: str

class BatteryData(NamedTuple):
    full: int
    high: int
    medium: int
    low: int

BATTERY_VALUES: Any
PUBLIC: str

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class NetatmoSensor(NetatmoBase, SensorEntity):
    entity_description: NetatmoSensorEntityDescription
    _id: Any
    _station_id: Any
    _device_name: Any
    _attr_name: Any
    _model: Any
    _attr_unique_id: Any
    def __init__(self, data_handler: NetatmoDataHandler, data_class_name: str, module_info: dict, description: NetatmoSensorEntityDescription) -> None: ...
    @property
    def _data(self) -> pyatmo.AsyncWeatherStationData: ...
    @property
    def available(self) -> bool: ...
    _attr_state: Any
    def async_update_callback(self) -> None: ...

def fix_angle(angle: int) -> int: ...
def process_angle(angle: int) -> str: ...
def process_battery(data: int, model: str) -> str: ...
def process_health(health: int) -> str: ...
def process_rf(strength: int) -> str: ...
def process_wifi(strength: int) -> str: ...

class NetatmoPublicSensor(NetatmoBase, SensorEntity):
    entity_description: NetatmoSensorEntityDescription
    _signal_name: Any
    area: Any
    _mode: Any
    _area_name: Any
    _id: Any
    _device_name: Any
    _attr_name: Any
    _show_on_map: Any
    _attr_unique_id: Any
    _model: Any
    def __init__(self, data_handler: NetatmoDataHandler, area: NetatmoArea, description: NetatmoSensorEntityDescription) -> None: ...
    @property
    def _data(self) -> pyatmo.AsyncPublicData: ...
    async def async_added_to_hass(self) -> None: ...
    _data_classes: Any
    async def async_config_update_callback(self, area: NetatmoArea) -> None: ...
    _attr_state: Any
    _attr_available: Any
    def async_update_callback(self) -> None: ...



from .const import ATTR_PASSIVE as ATTR_PASSIVE, ATTR_RADIUS as ATTR_RADIUS, CONF_PASSIVE as CONF_PASSIVE, DOMAIN as DOMAIN, HOME_ZONE as HOME_ZONE
from homeassistant import config_entries as config_entries
from homeassistant.const import ATTR_EDITABLE as ATTR_EDITABLE, ATTR_LATITUDE as ATTR_LATITUDE, ATTR_LONGITUDE as ATTR_LONGITUDE, CONF_ICON as CONF_ICON, CONF_ID as CONF_ID, CONF_LATITUDE as CONF_LATITUDE, CONF_LONGITUDE as CONF_LONGITUDE, CONF_NAME as CONF_NAME, CONF_RADIUS as CONF_RADIUS, EVENT_CORE_CONFIG_UPDATE as EVENT_CORE_CONFIG_UPDATE, SERVICE_RELOAD as SERVICE_RELOAD, STATE_UNAVAILABLE as STATE_UNAVAILABLE
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, ServiceCall as ServiceCall, State as State, callback as callback
from homeassistant.helpers import collection as collection, entity as entity, entity_component as entity_component, service as service, storage as storage
from homeassistant.loader import bind_hass as bind_hass
from homeassistant.util.location import distance as distance
from typing import Any

_LOGGER: Any
DEFAULT_PASSIVE: bool
DEFAULT_RADIUS: int
ENTITY_ID_FORMAT: str
ENTITY_ID_HOME: Any
ICON_HOME: str
ICON_IMPORT: str
CREATE_FIELDS: Any
UPDATE_FIELDS: Any

def empty_value(value: Any) -> Any: ...

CONFIG_SCHEMA: Any
RELOAD_SERVICE_SCHEMA: Any
STORAGE_KEY = DOMAIN
STORAGE_VERSION: int

def async_active_zone(hass: HomeAssistant, latitude: float, longitude: float, radius: int = ...) -> Union[State, None]: ...
def in_zone(zone: State, latitude: float, longitude: float, radius: float = ...) -> bool: ...

class ZoneStorageCollection(collection.StorageCollection):
    CREATE_SCHEMA: Any
    UPDATE_SCHEMA: Any
    async def _process_create_data(self, data: dict) -> dict: ...
    def _get_suggested_id(self, info: dict) -> str: ...
    async def _update_data(self, data: dict, update_data: dict) -> dict: ...

async def async_setup(hass: HomeAssistant, config: dict) -> bool: ...
def _home_conf(hass: HomeAssistant) -> dict: ...
async def async_setup_entry(hass: HomeAssistant, config_entry: config_entries.ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, config_entry: config_entries.ConfigEntry) -> bool: ...

class Zone(entity.Entity):
    _config: Any
    editable: bool
    _attrs: Any
    def __init__(self, config: dict) -> None: ...
    @classmethod
    def from_yaml(cls, config: dict) -> Zone: ...
    @property
    def state(self) -> str: ...
    @property
    def name(self) -> str: ...
    @property
    def unique_id(self) -> Union[str, None]: ...
    @property
    def icon(self) -> Union[str, None]: ...
    @property
    def extra_state_attributes(self) -> Union[dict, None]: ...
    @property
    def should_poll(self) -> bool: ...
    async def async_update_config(self, config: dict) -> None: ...
    def _generate_attrs(self) -> None: ...



from . import CONF_SERVERS as CONF_SERVERS, DATA_UPCLOUD as DATA_UPCLOUD, SIGNAL_UPDATE_UPCLOUD as SIGNAL_UPDATE_UPCLOUD, UpCloudServerEntity as UpCloudServerEntity
from homeassistant.components.switch import PLATFORM_SCHEMA as PLATFORM_SCHEMA, SwitchEntity as SwitchEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_USERNAME as CONF_USERNAME, STATE_OFF as STATE_OFF
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.dispatcher import dispatcher_send as dispatcher_send
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class UpCloudSwitch(UpCloudServerEntity, SwitchEntity):
    def turn_on(self, **kwargs: Any) -> None: ...
    def turn_off(self, **kwargs: Any) -> None: ...



from .const import BPUP_SUBS as BPUP_SUBS, DOMAIN as DOMAIN, HUB as HUB
from .entity import BondEntity as BondEntity
from .utils import BondHub as BondHub
from bond_api import BPUPSubscriptions as BPUPSubscriptions
from homeassistant.components.switch import SwitchEntity as SwitchEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class BondSwitch(BondEntity, SwitchEntity):
    _attr_is_on: Any
    def _apply_state(self, state: dict) -> None: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...



from . import CONF_SERVERS as CONF_SERVERS, DATA_UPCLOUD as DATA_UPCLOUD, UpCloudServerEntity as UpCloudServerEntity
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity, PLATFORM_SCHEMA as PLATFORM_SCHEMA
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_USERNAME as CONF_USERNAME
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class UpCloudBinarySensor(UpCloudServerEntity, BinarySensorEntity): ...



from .exceptions import DeviceNotFound as DeviceNotFound, InvalidDeviceAutomationConfig as InvalidDeviceAutomationConfig
from homeassistant.components import websocket_api as websocket_api
from homeassistant.const import CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_PLATFORM as CONF_PLATFORM
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_registry import async_entries_for_device as async_entries_for_device
from homeassistant.loader import IntegrationNotFound as IntegrationNotFound
from homeassistant.requirements import async_get_integration_with_requirements as async_get_integration_with_requirements
from types import ModuleType
from typing import Any

DOMAIN: str
DEVICE_TRIGGER_BASE_SCHEMA: Any
TYPES: Any

async def async_setup(hass, config): ...
async def async_get_device_automation_platform(hass: HomeAssistant, domain: str, automation_type: str) -> ModuleType: ...
async def _async_get_device_automations_from_domain(hass, domain, automation_type, device_id): ...
async def _async_get_device_automations(hass, automation_type, device_id): ...
async def _async_get_device_automation_capabilities(hass, automation_type, automation): ...
def handle_device_errors(func): ...
async def websocket_device_automation_list_actions(hass, connection, msg) -> None: ...
async def websocket_device_automation_list_conditions(hass, connection, msg) -> None: ...
async def websocket_device_automation_list_triggers(hass, connection, msg) -> None: ...
async def websocket_device_automation_get_action_capabilities(hass, connection, msg) -> None: ...
async def websocket_device_automation_get_condition_capabilities(hass, connection, msg) -> None: ...
async def websocket_device_automation_get_trigger_capabilities(hass, connection, msg) -> None: ...



from .const import DOMAIN as DOMAIN
from collections.abc import Awaitable
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers import singleton as singleton, storage as storage
from typing import Any, Callable, Literal, TypedDict, Union

STORAGE_VERSION: int
STORAGE_KEY = DOMAIN

async def async_get_manager(hass: HomeAssistant) -> EnergyManager: ...

class FlowFromGridSourceType(TypedDict):
    stat_energy_from: str
    stat_cost: Union[str, None]
    entity_energy_from: Union[str, None]
    entity_energy_price: Union[str, None]
    number_energy_price: Union[float, None]

class FlowToGridSourceType(TypedDict):
    stat_energy_to: str
    stat_compensation: Union[str, None]
    entity_energy_from: Union[str, None]
    entity_energy_price: Union[str, None]
    number_energy_price: Union[float, None]

class GridSourceType(TypedDict):
    type: Literal[grid]
    flow_from: list[FlowFromGridSourceType]
    flow_to: list[FlowToGridSourceType]
    cost_adjustment_day: float

class SolarSourceType(TypedDict):
    type: Literal[solar]
    stat_energy_from: str
    config_entry_solar_forecast: Union[list[str], None]
SourceType = Union[GridSourceType, SolarSourceType]

class DeviceConsumption(TypedDict):
    stat_consumption: str

class EnergyPreferences(TypedDict):
    energy_sources: list[SourceType]
    device_consumption: list[DeviceConsumption]

class EnergyPreferencesUpdate(EnergyPreferences): ...

def _flow_from_ensure_single_price(val: FlowFromGridSourceType) -> FlowFromGridSourceType: ...

FLOW_FROM_GRID_SOURCE_SCHEMA: Any
FLOW_TO_GRID_SOURCE_SCHEMA: Any

def _generate_unique_value_validator(key: str) -> Callable[[list[dict]], list[dict]]: ...

GRID_SOURCE_SCHEMA: Any
SOLAR_SOURCE_SCHEMA: Any

def check_type_limits(value: list[SourceType]) -> list[SourceType]: ...

ENERGY_SOURCE_SCHEMA: Any
DEVICE_CONSUMPTION_SCHEMA: Any

class EnergyManager:
    _hass: Any
    _store: Any
    data: Any
    _update_listeners: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    async def async_initialize(self) -> None: ...
    @staticmethod
    def default_preferences() -> EnergyPreferences: ...
    async def async_update(self, update: EnergyPreferencesUpdate) -> None: ...
    def async_listen_updates(self, update_listener: Callable[[], Awaitable]) -> None: ...



from .const import CONF_BAUD_RATE as CONF_BAUD_RATE, CONF_DEVICE as CONF_DEVICE, CONF_GATEWAY_TYPE as CONF_GATEWAY_TYPE, CONF_GATEWAY_TYPE_MQTT as CONF_GATEWAY_TYPE_MQTT, CONF_GATEWAY_TYPE_SERIAL as CONF_GATEWAY_TYPE_SERIAL, CONF_PERSISTENCE_FILE as CONF_PERSISTENCE_FILE, CONF_RETAIN as CONF_RETAIN, CONF_TCP_PORT as CONF_TCP_PORT, CONF_TOPIC_IN_PREFIX as CONF_TOPIC_IN_PREFIX, CONF_TOPIC_OUT_PREFIX as CONF_TOPIC_OUT_PREFIX, CONF_VERSION as CONF_VERSION, ConfGatewayType as ConfGatewayType, DOMAIN as DOMAIN, GatewayId as GatewayId, MYSENSORS_GATEWAYS as MYSENSORS_GATEWAYS, MYSENSORS_GATEWAY_START_TASK as MYSENSORS_GATEWAY_START_TASK
from .handler import HANDLERS as HANDLERS
from .helpers import discover_mysensors_platform as discover_mysensors_platform, on_unload as on_unload, validate_child as validate_child, validate_node as validate_node
from homeassistant.components.mqtt.models import ReceivePayloadType as ReceivePayloadType
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, callback as callback
from mysensors import BaseAsyncGateway as BaseAsyncGateway, Message as Message, Sensor as Sensor
from typing import Any, Callable

_LOGGER: Any
GATEWAY_READY_TIMEOUT: float
MQTT_COMPONENT: str

def is_serial_port(value: str) -> str: ...
def is_socket_address(value: str) -> str: ...
async def try_connect(hass: HomeAssistant, gateway_type: ConfGatewayType, user_input: dict[str, Any]) -> bool: ...
def get_mysensors_gateway(hass: HomeAssistant, gateway_id: GatewayId) -> Union[BaseAsyncGateway, None]: ...
async def setup_gateway(hass: HomeAssistant, entry: ConfigEntry) -> Union[BaseAsyncGateway, None]: ...
async def _get_gateway(hass: HomeAssistant, gateway_type: ConfGatewayType, device: str, version: str, event_callback: Callable[[Message], None], persistence_file: Union[str, None] = ..., baud_rate: Union[int, None] = ..., tcp_port: Union[int, None] = ..., topic_in_prefix: Union[str, None] = ..., topic_out_prefix: Union[str, None] = ..., retain: bool = ..., persistence: bool = ...) -> Union[BaseAsyncGateway, None]: ...
async def finish_setup(hass: HomeAssistant, entry: ConfigEntry, gateway: BaseAsyncGateway) -> None: ...
async def _discover_persistent_devices(hass: HomeAssistant, entry: ConfigEntry, gateway: BaseAsyncGateway) -> None: ...
async def gw_stop(hass: HomeAssistant, entry: ConfigEntry, gateway: BaseAsyncGateway) -> None: ...
async def _gw_start(hass: HomeAssistant, entry: ConfigEntry, gateway: BaseAsyncGateway) -> None: ...
def _gw_callback_factory(hass: HomeAssistant, gateway_id: GatewayId) -> Callable[[Message], None]: ...



from . import HuaweiLteBaseEntity as HuaweiLteBaseEntity
from .const import DOMAIN as DOMAIN, KEY_MONITORING_CHECK_NOTIFICATIONS as KEY_MONITORING_CHECK_NOTIFICATIONS, KEY_MONITORING_STATUS as KEY_MONITORING_STATUS, KEY_WLAN_WIFI_FEATURE_SWITCH as KEY_WLAN_WIFI_FEATURE_SWITCH
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

_LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class HuaweiLteBaseBinarySensor(HuaweiLteBaseEntity, BinarySensorEntity):
    key: str
    item: str
    _raw_state: Union[str, None]
    @property
    def entity_registry_enabled_default(self) -> bool: ...
    @property
    def _device_unique_id(self) -> str: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    _available: bool
    async def async_update(self) -> None: ...
    def __init__(self, router, available, unsub_handlers, raw_state) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

CONNECTION_STATE_ATTRIBUTES: Any

class HuaweiLteMobileConnectionBinarySensor(HuaweiLteBaseBinarySensor):
    key: Any
    item: str
    def __attrs_post_init__(self) -> None: ...
    @property
    def _entity_name(self) -> str: ...
    @property
    def is_on(self) -> bool: ...
    @property
    def assumed_state(self) -> bool: ...
    @property
    def icon(self) -> str: ...
    @property
    def entity_registry_enabled_default(self) -> bool: ...
    @property
    def extra_state_attributes(self) -> Union[dict[str, Any], None]: ...
    def __init__(self, router, available, unsub_handlers, raw_state) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class HuaweiLteBaseWifiStatusBinarySensor(HuaweiLteBaseBinarySensor):
    @property
    def is_on(self) -> bool: ...
    @property
    def assumed_state(self) -> bool: ...
    @property
    def icon(self) -> str: ...

class HuaweiLteWifiStatusBinarySensor(HuaweiLteBaseWifiStatusBinarySensor):
    key: Any
    item: str
    def __attrs_post_init__(self) -> None: ...
    @property
    def _entity_name(self) -> str: ...
    def __init__(self, router, available, unsub_handlers, raw_state) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class HuaweiLteWifi24ghzStatusBinarySensor(HuaweiLteBaseWifiStatusBinarySensor):
    key: Any
    item: str
    def __attrs_post_init__(self) -> None: ...
    @property
    def _entity_name(self) -> str: ...
    def __init__(self, router, available, unsub_handlers, raw_state) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class HuaweiLteWifi5ghzStatusBinarySensor(HuaweiLteBaseWifiStatusBinarySensor):
    key: Any
    item: str
    def __attrs_post_init__(self) -> None: ...
    @property
    def _entity_name(self) -> str: ...
    def __init__(self, router, available, unsub_handlers, raw_state) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class HuaweiLteSmsStorageFullBinarySensor(HuaweiLteBaseBinarySensor):
    key: Any
    item: str
    def __attrs_post_init__(self) -> None: ...
    @property
    def _entity_name(self) -> str: ...
    @property
    def is_on(self) -> bool: ...
    @property
    def assumed_state(self) -> bool: ...
    @property
    def icon(self) -> str: ...
    def __init__(self, router, available, unsub_handlers, raw_state) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...



from typing import Any

CONF_ADDON_DEVICE: str
CONF_ADDON_EMULATE_HARDWARE: str
CONF_ADDON_LOG_LEVEL: str
CONF_ADDON_NETWORK_KEY: str
CONF_INTEGRATION_CREATED_ADDON: str
CONF_NETWORK_KEY: str
CONF_USB_PATH: str
CONF_USE_ADDON: str
CONF_DATA_COLLECTION_OPTED_IN: str
DOMAIN: str
DATA_CLIENT: str
DATA_PLATFORM_SETUP: str
EVENT_DEVICE_ADDED_TO_REGISTRY: Any
LOGGER: Any
ZWAVE_JS_VALUE_NOTIFICATION_EVENT: Any
ZWAVE_JS_NOTIFICATION_EVENT: Any
ZWAVE_JS_VALUE_UPDATED_EVENT: Any
ATTR_NODE_ID: str
ATTR_HOME_ID: str
ATTR_ENDPOINT: str
ATTR_LABEL: str
ATTR_VALUE: str
ATTR_VALUE_RAW: str
ATTR_COMMAND_CLASS: str
ATTR_COMMAND_CLASS_NAME: str
ATTR_TYPE: str
ATTR_PROPERTY_NAME: str
ATTR_PROPERTY_KEY_NAME: str
ATTR_PROPERTY: str
ATTR_PROPERTY_KEY: str
ATTR_PARAMETERS: str
ATTR_EVENT: str
ATTR_EVENT_LABEL: str
ATTR_EVENT_TYPE: str
ATTR_EVENT_DATA: str
ATTR_DATA_TYPE: str
ATTR_WAIT_FOR_RESULT: str
ATTR_OPTIONS: str
ATTR_NODE: str
ATTR_ZWAVE_VALUE: str
SERVICE_SET_VALUE: str
SERVICE_RESET_METER: str
SERVICE_MULTICAST_SET_VALUE: str
SERVICE_PING: str
SERVICE_REFRESH_VALUE: str
SERVICE_SET_CONFIG_PARAMETER: str
SERVICE_BULK_SET_PARTIAL_CONFIG_PARAMETERS: str
ATTR_NODES: str
ATTR_CONFIG_PARAMETER: str
ATTR_CONFIG_PARAMETER_BITMASK: str
ATTR_CONFIG_VALUE: str
ATTR_REFRESH_ALL_VALUES: str
ATTR_BROADCAST: str
ATTR_METER_TYPE: str
ADDON_SLUG: str



from .const import CONF_APP_KEY as CONF_APP_KEY, DOMAIN as DOMAIN
from homeassistant import config_entries as config_entries
from homeassistant.const import CONF_API_KEY as CONF_API_KEY
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers import aiohttp_client as aiohttp_client
from typing import Any

class AmbientStationFlowHandler(config_entries.ConfigFlow):
    VERSION: int
    data_schema: Any
    def __init__(self) -> None: ...
    async def _show_form(self, errors: Union[dict, None] = ...) -> FlowResult: ...
    async def async_step_user(self, user_input: Union[dict, None] = ...) -> FlowResult: ...



import logging
from .const import CHILD_CALLBACK as CHILD_CALLBACK, CONF_DEVICE as CONF_DEVICE, DOMAIN as DOMAIN, DevId as DevId, GatewayId as GatewayId, NODE_CALLBACK as NODE_CALLBACK, PLATFORM_TYPES as PLATFORM_TYPES, UPDATE_DELAY as UPDATE_DELAY
from homeassistant.const import ATTR_BATTERY_LEVEL as ATTR_BATTERY_LEVEL, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo, Entity as Entity
from mysensors import BaseAsyncGateway as BaseAsyncGateway, Sensor as Sensor
from mysensors.sensor import ChildSensor as ChildSensor
from typing import Any

_LOGGER: Any
ATTR_CHILD_ID: str
ATTR_DESCRIPTION: str
ATTR_DEVICE: str
ATTR_NODE_ID: str
ATTR_HEARTBEAT: str
MYSENSORS_PLATFORM_DEVICES: str

class MySensorsDevice:
    hass: HomeAssistant
    gateway_id: Any
    gateway: Any
    node_id: Any
    child_id: Any
    value_type: Any
    child_type: Any
    _values: Any
    _update_scheduled: bool
    def __init__(self, gateway_id: GatewayId, gateway: BaseAsyncGateway, node_id: int, child_id: int, value_type: int) -> None: ...
    @property
    def dev_id(self) -> DevId: ...
    @property
    def _logger(self) -> logging.Logger: ...
    async def async_will_remove_from_hass(self) -> None: ...
    @property
    def _node(self) -> Sensor: ...
    @property
    def _child(self) -> ChildSensor: ...
    @property
    def sketch_name(self) -> str: ...
    @property
    def sketch_version(self) -> str: ...
    @property
    def node_name(self) -> str: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    @property
    def name(self) -> str: ...
    @property
    def _extra_attributes(self) -> dict[str, Any]: ...
    async def async_update(self) -> None: ...
    async def _async_update_callback(self) -> None: ...
    def async_update_callback(self) -> None: ...

def get_mysensors_devices(hass: HomeAssistant, domain: str) -> dict[DevId, MySensorsDevice]: ...

class MySensorsEntity(MySensorsDevice, Entity):
    @property
    def should_poll(self) -> bool: ...
    @property
    def available(self) -> bool: ...
    @property
    def extra_state_attributes(self) -> dict[str, Any]: ...
    async def _async_update_callback(self) -> None: ...
    async def async_added_to_hass(self) -> None: ...



from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.loader import bind_hass as bind_hass
from typing import Callable, TypeVar

T = TypeVar('T')
FUNC = Callable[[HomeAssistant], T]

def singleton(data_key: str) -> Callable[[FUNC], FUNC]: ...



from . import get_device_wrapper as get_device_wrapper
from .const import ATTR_CHANNEL as ATTR_CHANNEL, ATTR_CLICK_TYPE as ATTR_CLICK_TYPE, CONF_SUBTYPE as CONF_SUBTYPE, DOMAIN as DOMAIN, EVENT_SHELLY_CLICK as EVENT_SHELLY_CLICK, INPUTS_EVENTS_SUBTYPES as INPUTS_EVENTS_SUBTYPES, SHBTN_INPUTS_EVENTS_TYPES as SHBTN_INPUTS_EVENTS_TYPES, SHBTN_MODELS as SHBTN_MODELS, SUPPORTED_INPUTS_EVENTS_TYPES as SUPPORTED_INPUTS_EVENTS_TYPES
from .utils import get_input_triggers as get_input_triggers
from homeassistant.components.automation import AutomationActionType as AutomationActionType
from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA as DEVICE_TRIGGER_BASE_SCHEMA
from homeassistant.components.device_automation.exceptions import InvalidDeviceAutomationConfig as InvalidDeviceAutomationConfig
from homeassistant.const import ATTR_DEVICE_ID as ATTR_DEVICE_ID, CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_EVENT as CONF_EVENT, CONF_PLATFORM as CONF_PLATFORM, CONF_TYPE as CONF_TYPE
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, HomeAssistant as HomeAssistant
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any, Final

TRIGGER_SCHEMA: Final[Any]

async def async_validate_trigger_config(hass: HomeAssistant, config: dict[str, Any]) -> dict[str, Any]: ...
async def async_get_triggers(hass: HomeAssistant, device_id: str) -> list[dict[str, str]]: ...
async def async_attach_trigger(hass: HomeAssistant, config: ConfigType, action: AutomationActionType, automation_info: dict) -> CALLBACK_TYPE: ...



from .const import CONF_LOCATION as CONF_LOCATION, CONF_STATISTICS_ONLY as CONF_STATISTICS_ONLY, DATA_KEY_API as DATA_KEY_API, DATA_KEY_COORDINATOR as DATA_KEY_COORDINATOR, DEFAULT_LOCATION as DEFAULT_LOCATION, DEFAULT_NAME as DEFAULT_NAME, DEFAULT_SSL as DEFAULT_SSL, DEFAULT_VERIFY_SSL as DEFAULT_VERIFY_SSL, DOMAIN as DOMAIN, MIN_TIME_BETWEEN_UPDATES as MIN_TIME_BETWEEN_UPDATES
from hole import Hole
from homeassistant.config_entries import ConfigEntry as ConfigEntry, SOURCE_IMPORT as SOURCE_IMPORT
from homeassistant.const import CONF_API_KEY as CONF_API_KEY, CONF_HOST as CONF_HOST, CONF_NAME as CONF_NAME, CONF_SSL as CONF_SSL, CONF_VERIFY_SSL as CONF_VERIFY_SSL
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import ConfigEntryNotReady as ConfigEntryNotReady
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity, DataUpdateCoordinator as DataUpdateCoordinator, UpdateFailed as UpdateFailed
from typing import Any

_LOGGER: Any
PI_HOLE_SCHEMA: Any
CONFIG_SCHEMA: Any

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
def _async_platforms(entry: ConfigEntry) -> list[str]: ...

class PiHoleEntity(CoordinatorEntity):
    api: Any
    _name: Any
    _server_unique_id: Any
    def __init__(self, api: Hole, coordinator: DataUpdateCoordinator, name: str, server_unique_id: str) -> None: ...
    @property
    def icon(self) -> str: ...
    @property
    def device_info(self) -> DeviceInfo: ...



import jinja2
from collections.abc import Generator, Iterable
from contextvars import ContextVar
from datetime import datetime
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, ATTR_LATITUDE as ATTR_LATITUDE, ATTR_LONGITUDE as ATTR_LONGITUDE, ATTR_UNIT_OF_MEASUREMENT as ATTR_UNIT_OF_MEASUREMENT, LENGTH_METERS as LENGTH_METERS, STATE_UNKNOWN as STATE_UNKNOWN
from homeassistant.core import HomeAssistant as HomeAssistant, State as State, callback as callback, split_entity_id as split_entity_id, valid_entity_id as valid_entity_id
from homeassistant.exceptions import TemplateError as TemplateError
from homeassistant.helpers import device_registry as device_registry, entity_registry as entity_registry
from homeassistant.helpers.typing import TemplateVarsType as TemplateVarsType
from homeassistant.loader import bind_hass as bind_hass
from homeassistant.util import convert as convert
from homeassistant.util.async_ import run_callback_threadsafe as run_callback_threadsafe
from homeassistant.util.thread import ThreadWithException as ThreadWithException
from jinja2.sandbox import ImmutableSandboxedEnvironment
from typing import Any

_LOGGER: Any
_SENTINEL: Any
DATE_STR_FORMAT: str
_RENDER_INFO: str
_ENVIRONMENT: str
_ENVIRONMENT_LIMITED: str
_ENVIRONMENT_STRICT: str
_RE_JINJA_DELIMITERS: Any
_IS_NUMERIC: Any
_RESERVED_NAMES: Any
_GROUP_DOMAIN_PREFIX: str
_COLLECTABLE_STATE_ATTRIBUTES: Any
ALL_STATES_RATE_LIMIT: Any
DOMAIN_STATES_RATE_LIMIT: Any
template_cv: ContextVar[Union[str, None]]

def attach(hass: HomeAssistant, obj: Any) -> None: ...
def render_complex(value: Any, variables: TemplateVarsType = ..., limited: bool = ...) -> Any: ...
def is_complex(value: Any) -> bool: ...
def is_template_string(maybe_template: str) -> bool: ...

class ResultWrapper:
    render_result: Union[str, None]

def gen_result_wrapper(kls): ...

class TupleWrapper(tuple, ResultWrapper):
    def __new__(cls, value: tuple, *, render_result: Union[str, None] = ...) -> TupleWrapper: ...
    render_result: Any
    def __init__(self, value: tuple, *, render_result: Union[str, None] = ...) -> None: ...
    def __str__(self) -> str: ...

RESULT_WRAPPERS: dict[type, type]

def _true(arg: str) -> bool: ...
def _false(arg: str) -> bool: ...

class RenderInfo:
    template: Any
    filter_lifecycle: Any
    filter: Any
    _result: Any
    is_static: bool
    exception: Any
    all_states: bool
    all_states_lifecycle: bool
    domains: Any
    domains_lifecycle: Any
    entities: Any
    rate_limit: Any
    has_time: bool
    def __init__(self, template: Template) -> None: ...
    def __repr__(self) -> str: ...
    def _filter_domains_and_entities(self, entity_id: str) -> bool: ...
    def _filter_entities(self, entity_id: str) -> bool: ...
    def _filter_lifecycle_domains(self, entity_id: str) -> bool: ...
    def result(self) -> str: ...
    def _freeze_static(self) -> None: ...
    def _freeze_sets(self) -> None: ...
    def _freeze(self) -> None: ...

class Template:
    __slots__: Any
    template: Any
    _compiled_code: Any
    _compiled: Any
    hass: Any
    is_static: Any
    _exc_info: Any
    _limited: Any
    _strict: Any
    def __init__(self, template, hass: Any | None = ...) -> None: ...
    @property
    def _env(self) -> TemplateEnvironment: ...
    def ensure_valid(self) -> None: ...
    def render(self, variables: TemplateVarsType = ..., parse_result: bool = ..., limited: bool = ..., **kwargs: Any) -> Any: ...
    def async_render(self, variables: TemplateVarsType = ..., parse_result: bool = ..., limited: bool = ..., strict: bool = ..., **kwargs: Any) -> Any: ...
    def _parse_result(self, render_result: str) -> Any: ...
    async def async_render_will_timeout(self, timeout: float, variables: TemplateVarsType = ..., strict: bool = ..., **kwargs: Any) -> bool: ...
    def async_render_to_info(self, variables: TemplateVarsType = ..., strict: bool = ..., **kwargs: Any) -> RenderInfo: ...
    def render_with_possible_json_value(self, value, error_value=...): ...
    def async_render_with_possible_json_value(self, value, error_value=..., variables: Any | None = ...): ...
    def _ensure_compiled(self, limited: bool = ..., strict: bool = ...) -> jinja2.Template: ...
    def __eq__(self, other): ...
    def __hash__(self) -> int: ...
    def __repr__(self) -> str: ...

class AllStates:
    _hass: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    def __getattr__(self, name): ...
    __getitem__: Any
    def _collect_all(self) -> None: ...
    def _collect_all_lifecycle(self) -> None: ...
    def __iter__(self): ...
    def __len__(self) -> int: ...
    def __call__(self, entity_id): ...
    def __repr__(self) -> str: ...

class DomainStates:
    _hass: Any
    _domain: Any
    def __init__(self, hass: HomeAssistant, domain: str) -> None: ...
    def __getattr__(self, name): ...
    __getitem__: Any
    def _collect_domain(self) -> None: ...
    def _collect_domain_lifecycle(self) -> None: ...
    def __iter__(self): ...
    def __len__(self) -> int: ...
    def __repr__(self) -> str: ...

class TemplateState(State):
    __slots__: Any
    _hass: Any
    _state: Any
    _collect: Any
    def __init__(self, hass: HomeAssistant, state: State, collect: bool = ...) -> None: ...
    def _collect_state(self) -> None: ...
    def __getitem__(self, item): ...
    @property
    def entity_id(self): ...
    @property
    def state(self): ...
    @property
    def attributes(self): ...
    @property
    def last_changed(self): ...
    @property
    def last_updated(self): ...
    @property
    def context(self): ...
    @property
    def domain(self): ...
    @property
    def object_id(self): ...
    @property
    def name(self): ...
    @property
    def state_with_unit(self) -> str: ...
    def __eq__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...

def _collect_state(hass: HomeAssistant, entity_id: str) -> None: ...
def _state_generator(hass: HomeAssistant, domain: Union[str, None]) -> Generator: ...
def _get_state_if_valid(hass: HomeAssistant, entity_id: str) -> Union[TemplateState, None]: ...
def _get_state(hass: HomeAssistant, entity_id: str) -> Union[TemplateState, None]: ...
def _get_template_state_from_state(hass: HomeAssistant, entity_id: str, state: Union[State, None]) -> Union[TemplateState, None]: ...
def _resolve_state(hass: HomeAssistant, entity_id_or_state: Any) -> Union[State, TemplateState, None]: ...
def result_as_boolean(template_result: Union[str, None]) -> bool: ...
def expand(hass: HomeAssistant, *args: Any) -> Iterable[State]: ...
def device_entities(hass: HomeAssistant, _device_id: str) -> Iterable[str]: ...
def device_id(hass: HomeAssistant, entity_id: str) -> Union[str, None]: ...
def device_attr(hass: HomeAssistant, device_or_entity_id: str, attr_name: str) -> Any: ...
def is_device_attr(hass: HomeAssistant, device_or_entity_id: str, attr_name: str, attr_value: Any) -> bool: ...
def closest(hass, *args): ...
def closest_filter(hass, *args): ...
def distance(hass, *args): ...
def is_state(hass: HomeAssistant, entity_id: str, state: State) -> bool: ...
def is_state_attr(hass: HomeAssistant, entity_id: str, name: str, value: Any) -> bool: ...
def state_attr(hass: HomeAssistant, entity_id: str, name: str) -> Any: ...
def now(hass: HomeAssistant) -> datetime: ...
def utcnow(hass: HomeAssistant) -> datetime: ...
def forgiving_round(value, precision: int = ..., method: str = ...): ...
def multiply(value, amount): ...
def logarithm(value, base=...): ...
def sine(value): ...
def cosine(value): ...
def tangent(value): ...
def arc_sine(value): ...
def arc_cosine(value): ...
def arc_tangent(value): ...
def arc_tangent2(*args): ...
def square_root(value): ...
def timestamp_custom(value, date_format=..., local: bool = ...): ...
def timestamp_local(value): ...
def timestamp_utc(value): ...
def forgiving_as_timestamp(value): ...
def strptime(string, fmt): ...
def fail_when_undefined(value): ...
def forgiving_float(value): ...
def regex_match(value, find: str = ..., ignorecase: bool = ...): ...
def regex_replace(value: str = ..., find: str = ..., replace: str = ..., ignorecase: bool = ...): ...
def regex_search(value, find: str = ..., ignorecase: bool = ...): ...
def regex_findall_index(value, find: str = ..., index: int = ..., ignorecase: bool = ...): ...
def bitwise_and(first_value, second_value): ...
def bitwise_or(first_value, second_value): ...
def base64_encode(value): ...
def base64_decode(value): ...
def ordinal(value): ...
def from_json(value): ...
def to_json(value): ...
def random_every_time(context, values): ...
def relative_time(value): ...
def urlencode(value): ...
def _render_with_context(template_str: str, template: jinja2.Template, **kwargs: Any) -> str: ...

class LoggingUndefined(jinja2.Undefined):
    def _log_message(self) -> None: ...
    def _fail_with_undefined_error(self, *args, **kwargs): ...
    def __str__(self): ...
    def __iter__(self): ...
    def __bool__(self): ...

class TemplateEnvironment(ImmutableSandboxedEnvironment):
    hass: Any
    template_cache: Any
    def __init__(self, hass, limited: bool = ..., strict: bool = ...): ...
    def is_safe_callable(self, obj): ...
    def is_safe_attribute(self, obj, attr, value): ...
    def compile(self, source, name: Any | None = ..., filename: Any | None = ..., raw: bool = ..., defer_init: bool = ...): ...

_NO_HASS_ENV: Any



from .const import DOMAIN as DOMAIN
from homeassistant import config_entries as config_entries
from homeassistant.const import ATTR_NAME as ATTR_NAME, CONF_HOST as CONF_HOST
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from homeassistant.helpers.device_registry import format_mac as format_mac
from homeassistant.helpers.typing import DiscoveryInfoType as DiscoveryInfoType
from typing import Any

_LOGGER: Any

class NAMFlowHandler(config_entries.ConfigFlow):
    VERSION: int
    host: Any
    def __init__(self) -> None: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_zeroconf(self, discovery_info: DiscoveryInfoType) -> FlowResult: ...
    async def async_step_confirm_discovery(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def _async_get_mac(self, host: str) -> str: ...



import pysnmp.hlapi.asyncio as hlapi
from .const import DOMAIN as DOMAIN, SNMP as SNMP
from homeassistant.const import EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers import singleton as singleton
from typing import Any

_LOGGER: Any

def get_snmp_engine(hass: HomeAssistant) -> hlapi.SnmpEngine: ...



import voluptuous as vol
from collections.abc import Awaitable, Iterable
from homeassistant.auth.permissions.const import CAT_ENTITIES as CAT_ENTITIES, POLICY_CONTROL as POLICY_CONTROL
from homeassistant.const import ATTR_AREA_ID as ATTR_AREA_ID, ATTR_DEVICE_ID as ATTR_DEVICE_ID, ATTR_ENTITY_ID as ATTR_ENTITY_ID, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_SERVICE as CONF_SERVICE, CONF_SERVICE_DATA as CONF_SERVICE_DATA, CONF_SERVICE_TEMPLATE as CONF_SERVICE_TEMPLATE, CONF_TARGET as CONF_TARGET, ENTITY_MATCH_ALL as ENTITY_MATCH_ALL, ENTITY_MATCH_NONE as ENTITY_MATCH_NONE
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, ServiceCall as ServiceCall, callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError, TemplateError as TemplateError, Unauthorized as Unauthorized, UnknownUser as UnknownUser
from homeassistant.helpers import area_registry as area_registry, device_registry as device_registry, entity_registry as entity_registry, template as template
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.entity_platform import EntityPlatform as EntityPlatform
from homeassistant.helpers.typing import ConfigType as ConfigType, TemplateVarsType as TemplateVarsType
from homeassistant.loader import Integration as Integration, MAX_LOAD_CONCURRENTLY as MAX_LOAD_CONCURRENTLY, async_get_integration as async_get_integration, bind_hass as bind_hass
from homeassistant.util.async_ import gather_with_concurrency as gather_with_concurrency
from homeassistant.util.yaml import load_yaml as load_yaml
from homeassistant.util.yaml.loader import JSON_TYPE as JSON_TYPE
from typing import Any, Callable, TypedDict

CONF_SERVICE_ENTITY_ID: str
CONF_SERVICE_DATA_TEMPLATE: str
_LOGGER: Any
SERVICE_DESCRIPTION_CACHE: str

class ServiceParams(TypedDict):
    domain: str
    service: str
    service_data: dict[str, Any]
    target: Union[dict, None]

class ServiceTargetSelector:
    entity_ids: Any
    device_ids: Any
    area_ids: Any
    def __init__(self, service_call: ServiceCall) -> None: ...
    @property
    def has_any_selector(self) -> bool: ...

class SelectedEntities:
    referenced: set[str]
    indirectly_referenced: set[str]
    missing_devices: set[str]
    missing_areas: set[str]
    referenced_devices: set[str]
    def log_missing(self, missing_entities: set[str]) -> None: ...

def call_from_config(hass: HomeAssistant, config: ConfigType, blocking: bool = ..., variables: TemplateVarsType = ..., validate_config: bool = ...) -> None: ...
async def async_call_from_config(hass: HomeAssistant, config: ConfigType, blocking: bool = ..., variables: TemplateVarsType = ..., validate_config: bool = ..., context: Union[Context, None] = ...) -> None: ...
def async_prepare_call_from_config(hass: HomeAssistant, config: ConfigType, variables: TemplateVarsType = ..., validate_config: bool = ...) -> ServiceParams: ...
def extract_entity_ids(hass: HomeAssistant, service_call: ServiceCall, expand_group: bool = ...) -> set[str]: ...
async def async_extract_entities(hass: HomeAssistant, entities: Iterable[Entity], service_call: ServiceCall, expand_group: bool = ...) -> list[Entity]: ...
async def async_extract_entity_ids(hass: HomeAssistant, service_call: ServiceCall, expand_group: bool = ...) -> set[str]: ...
def _has_match(ids: Union[str, list, None]) -> bool: ...
async def async_extract_referenced_entity_ids(hass: HomeAssistant, service_call: ServiceCall, expand_group: bool = ...) -> SelectedEntities: ...
async def async_extract_config_entry_ids(hass: HomeAssistant, service_call: ServiceCall, expand_group: bool = ...) -> set: ...
def _load_services_file(hass: HomeAssistant, integration: Integration) -> JSON_TYPE: ...
def _load_services_files(hass: HomeAssistant, integrations: Iterable[Integration]) -> list[JSON_TYPE]: ...
async def async_get_all_descriptions(hass: HomeAssistant) -> dict[str, dict[str, Any]]: ...
def async_set_service_schema(hass: HomeAssistant, domain: str, service: str, schema: dict[str, Any]) -> None: ...
async def entity_service_call(hass: HomeAssistant, platforms: Iterable[EntityPlatform], func: Union[str, Callable[..., Any]], call: ServiceCall, required_features: Union[Iterable[int], None] = ...) -> None: ...
async def _handle_entity_call(hass: HomeAssistant, entity: Entity, func: Union[str, Callable[..., Any]], data: Union[dict, ServiceCall], context: Context) -> None: ...
def async_register_admin_service(hass: HomeAssistant, domain: str, service: str, service_func: Callable[[ServiceCall], Union[Awaitable, None]], schema: vol.Schema = ...) -> None: ...
def verify_domain_control(hass: HomeAssistant, domain: str) -> Callable[[Callable[[ServiceCall], Any]], Callable[[ServiceCall], Any]]: ...

class ReloadServiceHelper:
    _service_func: Any
    _service_running: bool
    _service_condition: Any
    def __init__(self, service_func: Callable[[ServiceCall], Awaitable]) -> None: ...
    async def execute_service(self, service_call: ServiceCall) -> None: ...



from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_BATTERY_LEVEL as ATTR_BATTERY_LEVEL, ATTR_COMMAND as ATTR_COMMAND, SERVICE_TOGGLE as SERVICE_TOGGLE, SERVICE_TURN_OFF as SERVICE_TURN_OFF, SERVICE_TURN_ON as SERVICE_TURN_ON, STATE_IDLE as STATE_IDLE, STATE_ON as STATE_ON, STATE_PAUSED as STATE_PAUSED
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE, make_entity_service_schema as make_entity_service_schema
from homeassistant.helpers.entity import Entity as Entity, EntityDescription as EntityDescription, ToggleEntity as ToggleEntity, ToggleEntityDescription as ToggleEntityDescription
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.helpers.icon import icon_for_battery_level as icon_for_battery_level
from homeassistant.loader import bind_hass as bind_hass
from typing import Any

_LOGGER: Any
DOMAIN: str
SCAN_INTERVAL: Any
ATTR_BATTERY_ICON: str
ATTR_CLEANED_AREA: str
ATTR_FAN_SPEED: str
ATTR_FAN_SPEED_LIST: str
ATTR_PARAMS: str
ATTR_STATUS: str
SERVICE_CLEAN_SPOT: str
SERVICE_LOCATE: str
SERVICE_RETURN_TO_BASE: str
SERVICE_SEND_COMMAND: str
SERVICE_SET_FAN_SPEED: str
SERVICE_START_PAUSE: str
SERVICE_START: str
SERVICE_PAUSE: str
SERVICE_STOP: str
STATE_CLEANING: str
STATE_DOCKED: str
STATE_RETURNING: str
STATE_ERROR: str
STATES: Any
DEFAULT_NAME: str
SUPPORT_TURN_ON: int
SUPPORT_TURN_OFF: int
SUPPORT_PAUSE: int
SUPPORT_STOP: int
SUPPORT_RETURN_HOME: int
SUPPORT_FAN_SPEED: int
SUPPORT_BATTERY: int
SUPPORT_STATUS: int
SUPPORT_SEND_COMMAND: int
SUPPORT_LOCATE: int
SUPPORT_CLEAN_SPOT: int
SUPPORT_MAP: int
SUPPORT_STATE: int
SUPPORT_START: int

def is_on(hass, entity_id): ...
async def async_setup(hass, config): ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class _BaseVacuum(Entity):
    @property
    def supported_features(self) -> None: ...
    @property
    def battery_level(self) -> None: ...
    @property
    def battery_icon(self) -> None: ...
    @property
    def fan_speed(self) -> None: ...
    @property
    def fan_speed_list(self) -> None: ...
    @property
    def capability_attributes(self): ...
    @property
    def state_attributes(self): ...
    def stop(self, **kwargs) -> None: ...
    async def async_stop(self, **kwargs) -> None: ...
    def return_to_base(self, **kwargs) -> None: ...
    async def async_return_to_base(self, **kwargs) -> None: ...
    def clean_spot(self, **kwargs) -> None: ...
    async def async_clean_spot(self, **kwargs) -> None: ...
    def locate(self, **kwargs) -> None: ...
    async def async_locate(self, **kwargs) -> None: ...
    def set_fan_speed(self, fan_speed, **kwargs) -> None: ...
    async def async_set_fan_speed(self, fan_speed, **kwargs) -> None: ...
    def send_command(self, command, params: Any | None = ..., **kwargs) -> None: ...
    async def async_send_command(self, command, params: Any | None = ..., **kwargs) -> None: ...

class VacuumEntityDescription(ToggleEntityDescription): ...

class VacuumEntity(_BaseVacuum, ToggleEntity):
    entity_description: VacuumEntityDescription
    @property
    def status(self) -> None: ...
    @property
    def battery_icon(self): ...
    @property
    def state_attributes(self): ...
    def turn_on(self, **kwargs) -> None: ...
    async def async_turn_on(self, **kwargs) -> None: ...
    def turn_off(self, **kwargs) -> None: ...
    async def async_turn_off(self, **kwargs) -> None: ...
    def start_pause(self, **kwargs) -> None: ...
    async def async_start_pause(self, **kwargs) -> None: ...
    async def async_pause(self) -> None: ...
    async def async_start(self) -> None: ...

class VacuumDevice(VacuumEntity):
    def __init_subclass__(cls, **kwargs) -> None: ...

class StateVacuumEntityDescription(EntityDescription): ...

class StateVacuumEntity(_BaseVacuum):
    entity_description: StateVacuumEntityDescription
    @property
    def state(self) -> None: ...
    @property
    def battery_icon(self): ...
    def start(self) -> None: ...
    async def async_start(self) -> None: ...
    def pause(self) -> None: ...
    async def async_pause(self) -> None: ...
    async def async_turn_on(self, **kwargs) -> None: ...
    async def async_turn_off(self, **kwargs) -> None: ...
    async def async_toggle(self, **kwargs) -> None: ...

class StateVacuumDevice(StateVacuumEntity):
    def __init_subclass__(cls, **kwargs) -> None: ...



from .const import BRIDGE_MAKE as BRIDGE_MAKE
from bond_api import Bond as Bond
from homeassistant.util.async_ import gather_with_concurrency as gather_with_concurrency
from typing import Any

MAX_REQUESTS: int
_LOGGER: Any

class BondDevice:
    device_id: Any
    props: Any
    _attrs: Any
    def __init__(self, device_id: str, attrs: dict[str, Any], props: dict[str, Any]) -> None: ...
    def __repr__(self) -> str: ...
    @property
    def name(self) -> str: ...
    @property
    def type(self) -> str: ...
    @property
    def location(self) -> Union[str, None]: ...
    @property
    def template(self) -> Union[str, None]: ...
    @property
    def branding_profile(self) -> Union[str, None]: ...
    @property
    def trust_state(self) -> bool: ...
    def _has_any_action(self, actions: set[str]) -> bool: ...
    def supports_speed(self) -> bool: ...
    def supports_direction(self) -> bool: ...
    def supports_light(self) -> bool: ...
    def supports_up_light(self) -> bool: ...
    def supports_down_light(self) -> bool: ...
    def supports_set_brightness(self) -> bool: ...

class BondHub:
    bond: Any
    _bridge: Any
    _version: Any
    _devices: Any
    def __init__(self, bond: Bond) -> None: ...
    async def setup(self, max_devices: Union[int, None] = ...) -> None: ...
    @property
    def bond_id(self) -> Union[str, None]: ...
    @property
    def target(self) -> Union[str, None]: ...
    @property
    def model(self) -> Union[str, None]: ...
    @property
    def make(self) -> str: ...
    @property
    def name(self) -> str: ...
    @property
    def location(self) -> Union[str, None]: ...
    @property
    def fw_ver(self) -> Union[str, None]: ...
    @property
    def devices(self) -> list[BondDevice]: ...
    @property
    def is_bridge(self) -> bool: ...



from . import STATE_ECO as STATE_ECO, STATE_ELECTRIC as STATE_ELECTRIC, STATE_GAS as STATE_GAS, STATE_HEAT_PUMP as STATE_HEAT_PUMP, STATE_HIGH_DEMAND as STATE_HIGH_DEMAND, STATE_PERFORMANCE as STATE_PERFORMANCE
from homeassistant.components.group import GroupIntegrationRegistry as GroupIntegrationRegistry
from homeassistant.const import STATE_OFF as STATE_OFF
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback

def async_describe_on_off_states(hass: HomeAssistant, registry: GroupIntegrationRegistry) -> None: ...



from . import AccuWeatherDataUpdateCoordinator as AccuWeatherDataUpdateCoordinator
from .const import API_IMPERIAL as API_IMPERIAL, API_METRIC as API_METRIC, ATTRIBUTION as ATTRIBUTION, ATTR_FORECAST as ATTR_FORECAST, DOMAIN as DOMAIN, FORECAST_SENSOR_TYPES as FORECAST_SENSOR_TYPES, MANUFACTURER as MANUFACTURER, MAX_FORECAST_DAYS as MAX_FORECAST_DAYS, NAME as NAME, SENSOR_TYPES as SENSOR_TYPES
from .model import AccuWeatherSensorDescription as AccuWeatherSensorDescription
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION, CONF_NAME as CONF_NAME, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import StateType as StateType
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity
from typing import Any

PARALLEL_UPDATES: int

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class AccuWeatherSensor(CoordinatorEntity, SensorEntity):
    coordinator: AccuWeatherDataUpdateCoordinator
    entity_description: AccuWeatherSensorDescription
    _sensor_data: Any
    _attrs: Any
    _attr_name: Any
    _attr_unique_id: Any
    _unit_system: Any
    _attr_unit_of_measurement: Any
    _attr_device_info: Any
    forecast_day: Any
    def __init__(self, name: str, coordinator: AccuWeatherDataUpdateCoordinator, description: AccuWeatherSensorDescription, forecast_day: Union[int, None] = ...) -> None: ...
    @property
    def state(self) -> StateType: ...
    @property
    def extra_state_attributes(self) -> dict[str, Any]: ...
    def _handle_coordinator_update(self) -> None: ...

def _get_sensor_data(sensors: dict[str, Any], forecast_day: Union[int, None], kind: str) -> Any: ...



from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION, CONCENTRATION_MICROGRAMS_PER_CUBIC_METER as CONCENTRATION_MICROGRAMS_PER_CUBIC_METER
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.helpers.typing import ConfigType as ConfigType, StateType as StateType
from typing import Any, Final

_LOGGER: Final[Any]
ATTR_AQI: Final[str]
ATTR_CO2: Final[str]
ATTR_CO: Final[str]
ATTR_N2O: Final[str]
ATTR_NO: Final[str]
ATTR_NO2: Final[str]
ATTR_OZONE: Final[str]
ATTR_PM_0_1: Final[str]
ATTR_PM_10: Final[str]
ATTR_PM_2_5: Final[str]
ATTR_SO2: Final[str]
DOMAIN: Final[str]
ENTITY_ID_FORMAT: Final[Any]
SCAN_INTERVAL: Final[Any]
PROP_TO_ATTR: Final[dict[str, str]]

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class AirQualityEntity(Entity):
    @property
    def particulate_matter_2_5(self) -> StateType: ...
    @property
    def particulate_matter_10(self) -> StateType: ...
    @property
    def particulate_matter_0_1(self) -> StateType: ...
    @property
    def air_quality_index(self) -> StateType: ...
    @property
    def ozone(self) -> StateType: ...
    @property
    def carbon_monoxide(self) -> StateType: ...
    @property
    def carbon_dioxide(self) -> StateType: ...
    @property
    def attribution(self) -> StateType: ...
    @property
    def sulphur_dioxide(self) -> StateType: ...
    @property
    def nitrogen_oxide(self) -> StateType: ...
    @property
    def nitrogen_monoxide(self) -> StateType: ...
    @property
    def nitrogen_dioxide(self) -> StateType: ...
    @property
    def state_attributes(self) -> dict[str, Union[str, int, float]]: ...
    @property
    def state(self) -> StateType: ...
    @property
    def unit_of_measurement(self) -> str: ...



from .const import CONF_MYDEVOLO as CONF_MYDEVOLO, DEFAULT_MYDEVOLO as DEFAULT_MYDEVOLO, DOMAIN as DOMAIN, GATEWAY_SERIAL_PATTERN as GATEWAY_SERIAL_PATTERN, PLATFORMS as PLATFORMS
from devolo_home_control_api.mydevolo import Mydevolo
from homeassistant.components import zeroconf as zeroconf
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_PASSWORD as CONF_PASSWORD, CONF_USERNAME as CONF_USERNAME, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant
from homeassistant.exceptions import ConfigEntryAuthFailed as ConfigEntryAuthFailed, ConfigEntryNotReady as ConfigEntryNotReady
from types import MappingProxyType
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
def configure_mydevolo(conf: Union[dict[str, Any], MappingProxyType[str, Any]]) -> Mydevolo: ...



import json
from homeassistant.core import Event as Event, State as State
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from typing import Any, Callable

_LOGGER: Any

class SerializationError(HomeAssistantError): ...
class WriteError(HomeAssistantError): ...

def load_json(filename: str, default: Union[list, dict, None] = ...) -> Union[list, dict]: ...
def save_json(filename: str, data: Union[list, dict], private: bool = ..., *, encoder: Union[type[json.JSONEncoder], None] = ...) -> None: ...
def format_unserializable_data(data: dict[str, Any]) -> str: ...
def find_paths_unserializable_data(bad_data: Any, *, dump: Callable[[Any], str] = ...) -> dict[str, Any]: ...



import pathlib
from awesomeversion import AwesomeVersion
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.generated.dhcp import DHCP as DHCP
from homeassistant.generated.mqtt import MQTT as MQTT
from homeassistant.generated.ssdp import SSDP as SSDP
from homeassistant.generated.zeroconf import HOMEKIT as HOMEKIT, ZEROCONF as ZEROCONF
from homeassistant.util.async_ import gather_with_concurrency as gather_with_concurrency
from types import ModuleType
from typing import Any, Callable, TypeVar, TypedDict

CALLABLE_T = TypeVar('CALLABLE_T', bound=Callable[..., Any])
_LOGGER: Any
DATA_COMPONENTS: str
DATA_INTEGRATIONS: str
DATA_CUSTOM_COMPONENTS: str
PACKAGE_CUSTOM_COMPONENTS: str
PACKAGE_BUILTIN: str
CUSTOM_WARNING: str
_UNDEF: Any
MAX_LOAD_CONCURRENTLY: int

class Manifest(TypedDict):
    name: str
    disabled: str
    domain: str
    dependencies: list[str]
    after_dependencies: list[str]
    requirements: list[str]
    config_flow: bool
    documentation: str
    issue_tracker: str
    quality_scale: str
    iot_class: str
    mqtt: list[str]
    ssdp: list[dict[str, str]]
    zeroconf: list[Union[str, dict[str, str]]]
    dhcp: list[dict[str, str]]
    homekit: dict[str, list[str]]
    is_built_in: bool
    version: str
    codeowners: list[str]

def manifest_from_legacy_module(domain: str, module: ModuleType) -> Manifest: ...
async def _async_get_custom_components(hass: HomeAssistant) -> dict[str, Integration]: ...
async def async_get_custom_components(hass: HomeAssistant) -> dict[str, Integration]: ...
async def async_get_config_flows(hass: HomeAssistant) -> set[str]: ...
async def async_get_zeroconf(hass: HomeAssistant) -> dict[str, list[dict[str, str]]]: ...
async def async_get_dhcp(hass: HomeAssistant) -> list[dict[str, str]]: ...
async def async_get_homekit(hass: HomeAssistant) -> dict[str, str]: ...
async def async_get_ssdp(hass: HomeAssistant) -> dict[str, list[dict[str, str]]]: ...
async def async_get_mqtt(hass: HomeAssistant) -> dict[str, list[str]]: ...

class Integration:
    @classmethod
    def resolve_from_root(cls, hass: HomeAssistant, root_module: ModuleType, domain: str) -> Union[Integration, None]: ...
    hass: Any
    pkg_path: Any
    file_path: Any
    manifest: Any
    _all_dependencies_resolved: Any
    _all_dependencies: Any
    def __init__(self, hass: HomeAssistant, pkg_path: str, file_path: pathlib.Path, manifest: Manifest) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def disabled(self) -> Union[str, None]: ...
    @property
    def domain(self) -> str: ...
    @property
    def dependencies(self) -> list[str]: ...
    @property
    def after_dependencies(self) -> list[str]: ...
    @property
    def requirements(self) -> list[str]: ...
    @property
    def config_flow(self) -> bool: ...
    @property
    def documentation(self) -> Union[str, None]: ...
    @property
    def issue_tracker(self) -> Union[str, None]: ...
    @property
    def quality_scale(self) -> Union[str, None]: ...
    @property
    def iot_class(self) -> Union[str, None]: ...
    @property
    def mqtt(self) -> Union[list[str], None]: ...
    @property
    def ssdp(self) -> Union[list[dict[str, str]], None]: ...
    @property
    def zeroconf(self) -> Union[list[Union[str, dict[str, str]]], None]: ...
    @property
    def dhcp(self) -> Union[list[dict[str, str]], None]: ...
    @property
    def homekit(self) -> Union[dict[str, list[str]], None]: ...
    @property
    def is_built_in(self) -> bool: ...
    @property
    def version(self) -> Union[AwesomeVersion, None]: ...
    @property
    def all_dependencies(self) -> set[str]: ...
    @property
    def all_dependencies_resolved(self) -> bool: ...
    async def resolve_dependencies(self) -> bool: ...
    def get_component(self) -> ModuleType: ...
    def get_platform(self, platform_name: str) -> ModuleType: ...
    def _import_platform(self, platform_name: str) -> ModuleType: ...
    def __repr__(self) -> str: ...

async def async_get_integration(hass: HomeAssistant, domain: str) -> Integration: ...
async def _async_get_integration(hass: HomeAssistant, domain: str) -> Integration: ...

class LoaderError(Exception): ...

class IntegrationNotFound(LoaderError):
    domain: Any
    def __init__(self, domain: str) -> None: ...

class CircularDependency(LoaderError):
    from_domain: Any
    to_domain: Any
    def __init__(self, from_domain: str, to_domain: str) -> None: ...

def _load_file(hass: HomeAssistant, comp_or_platform: str, base_paths: list[str]) -> Union[ModuleType, None]: ...

class ModuleWrapper:
    _hass: Any
    _module: Any
    def __init__(self, hass: HomeAssistant, module: ModuleType) -> None: ...
    def __getattr__(self, attr: str) -> Any: ...

class Components:
    _hass: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    def __getattr__(self, comp_name: str) -> ModuleWrapper: ...

class Helpers:
    _hass: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    def __getattr__(self, helper_name: str) -> ModuleWrapper: ...

def bind_hass(func: CALLABLE_T) -> CALLABLE_T: ...
async def _async_component_dependencies(hass: HomeAssistant, start_domain: str, integration: Integration, loaded: set[str], loading: set[str]) -> set[str]: ...
def _async_mount_config_dir(hass: HomeAssistant) -> bool: ...
def _lookup_path(hass: HomeAssistant) -> list[str]: ...



from collections.abc import Iterable
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_COMMAND as ATTR_COMMAND, SERVICE_TOGGLE as SERVICE_TOGGLE, SERVICE_TURN_OFF as SERVICE_TURN_OFF, SERVICE_TURN_ON as SERVICE_TURN_ON, STATE_ON as STATE_ON
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE, make_entity_service_schema as make_entity_service_schema
from homeassistant.helpers.entity import ToggleEntity as ToggleEntity, ToggleEntityDescription as ToggleEntityDescription
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.loader import bind_hass as bind_hass
from typing import Any

_LOGGER: Any
ATTR_ACTIVITY: str
ATTR_ACTIVITY_LIST: str
ATTR_CURRENT_ACTIVITY: str
ATTR_COMMAND_TYPE: str
ATTR_DEVICE: str
ATTR_NUM_REPEATS: str
ATTR_DELAY_SECS: str
ATTR_HOLD_SECS: str
ATTR_ALTERNATIVE: str
ATTR_TIMEOUT: str
DOMAIN: str
SCAN_INTERVAL: Any
ENTITY_ID_FORMAT: Any
MIN_TIME_BETWEEN_SCANS: Any
SERVICE_SEND_COMMAND: str
SERVICE_LEARN_COMMAND: str
SERVICE_DELETE_COMMAND: str
SERVICE_SYNC: str
DEFAULT_NUM_REPEATS: int
DEFAULT_DELAY_SECS: float
DEFAULT_HOLD_SECS: int
SUPPORT_LEARN_COMMAND: int
SUPPORT_DELETE_COMMAND: int
SUPPORT_ACTIVITY: int
REMOTE_SERVICE_ACTIVITY_SCHEMA: Any

def is_on(hass: HomeAssistant, entity_id: str) -> bool: ...
async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class RemoteEntityDescription(ToggleEntityDescription): ...

class RemoteEntity(ToggleEntity):
    entity_description: RemoteEntityDescription
    _attr_activity_list: Union[list[str], None]
    _attr_current_activity: Union[str, None]
    _attr_supported_features: int
    @property
    def supported_features(self) -> int: ...
    @property
    def current_activity(self) -> Union[str, None]: ...
    @property
    def activity_list(self) -> Union[list[str], None]: ...
    @property
    def state_attributes(self) -> Union[dict[str, Any], None]: ...
    def send_command(self, command: Iterable[str], **kwargs: Any) -> None: ...
    async def async_send_command(self, command: Iterable[str], **kwargs: Any) -> None: ...
    def learn_command(self, **kwargs: Any) -> None: ...
    async def async_learn_command(self, **kwargs: Any) -> None: ...
    def delete_command(self, **kwargs: Any) -> None: ...
    async def async_delete_command(self, **kwargs: Any) -> None: ...

class RemoteDevice(RemoteEntity):
    def __init_subclass__(cls, **kwargs) -> None: ...



import abc
from .const import DOMAIN as DOMAIN
from .utils import BondDevice as BondDevice, BondHub as BondHub
from abc import abstractmethod
from bond_api import BPUPSubscriptions as BPUPSubscriptions
from homeassistant.core import callback as callback
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo, Entity as Entity
from homeassistant.helpers.event import async_track_time_interval as async_track_time_interval
from typing import Any

_LOGGER: Any
_FALLBACK_SCAN_INTERVAL: Any

class BondEntity(Entity, metaclass=abc.ABCMeta):
    _attr_should_poll: bool
    _hub: Any
    _device: Any
    _device_id: Any
    _sub_device: Any
    _attr_available: bool
    _bpup_subs: Any
    _update_lock: Any
    _initialized: bool
    _attr_unique_id: Any
    _attr_name: Any
    def __init__(self, hub: BondHub, device: BondDevice, bpup_subs: BPUPSubscriptions, sub_device: Union[str, None] = ...) -> None: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    async def async_update(self) -> None: ...
    async def _async_update_if_bpup_not_alive(self, *_: Any) -> None: ...
    _attr_assumed_state: Any
    async def _async_update_from_api(self) -> None: ...
    @abstractmethod
    def _apply_state(self, state: dict) -> None: ...
    def _async_state_callback(self, state: dict) -> None: ...
    def _async_bpup_callback(self, state: dict) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...



from .const import DATA_DEVICE_IDS as DATA_DEVICE_IDS, DEFAULT_ATTRIBUTION as DEFAULT_ATTRIBUTION, DOMAIN as DOMAIN, MANUFACTURER as MANUFACTURER, MODELS as MODELS, SIGNAL_NAME as SIGNAL_NAME
from .data_handler import NetatmoDataHandler as NetatmoDataHandler, PUBLICDATA_DATA_CLASS_NAME as PUBLICDATA_DATA_CLASS_NAME
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, callback as callback
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo, Entity as Entity
from typing import Any

class NetatmoBase(Entity):
    data_handler: Any
    _data_classes: Any
    _listeners: Any
    _device_name: str
    _id: str
    _model: str
    _attr_name: Any
    _attr_unique_id: Any
    _attr_extra_state_attributes: Any
    def __init__(self, data_handler: NetatmoDataHandler) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    def async_update_callback(self) -> None: ...
    @property
    def device_info(self) -> DeviceInfo: ...



from .const import DOMAIN as DOMAIN, FRITZ_SERVICES as FRITZ_SERVICES, SERVICE_REBOOT as SERVICE_REBOOT, SERVICE_RECONNECT as SERVICE_RECONNECT
from homeassistant.core import HomeAssistant as HomeAssistant, ServiceCall as ServiceCall
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers.service import async_extract_config_entry_ids as async_extract_config_entry_ids
from typing import Any

_LOGGER: Any

async def async_setup_services(hass: HomeAssistant) -> None: ...
async def _async_get_configured_fritz_tools(hass: HomeAssistant, service_call: ServiceCall) -> list: ...
async def async_unload_services(hass: HomeAssistant) -> None: ...



from homeassistant.const import CONF_SCAN_INTERVAL as CONF_SCAN_INTERVAL
from homeassistant.core import HomeAssistant as HomeAssistant, ServiceCall as ServiceCall
from homeassistant.helpers.discovery import async_load_platform as async_load_platform
from homeassistant.helpers.dispatcher import dispatcher_send as dispatcher_send
from homeassistant.helpers.event import async_track_time_interval as async_track_time_interval
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

DOMAIN: str
DATA_UPDATED: Any
_LOGGER: Any
CONF_MANUAL: str
DEFAULT_INTERVAL: Any
CONFIG_SCHEMA: Any

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...

class SpeedtestData:
    data: Any
    _hass: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    def update(self) -> None: ...



import voluptuous as vol
from .const import ATTR_DEVICES as ATTR_DEVICES, ATTR_GATEWAY_ID as ATTR_GATEWAY_ID, DOMAIN as DOMAIN, DevId as DevId, FLAT_PLATFORM_TYPES as FLAT_PLATFORM_TYPES, GatewayId as GatewayId, MYSENSORS_DISCOVERY as MYSENSORS_DISCOVERY, MYSENSORS_ON_UNLOAD as MYSENSORS_ON_UNLOAD, SensorType as SensorType, TYPE_TO_PLATFORMS as TYPE_TO_PLATFORMS, ValueType as ValueType
from collections import defaultdict
from homeassistant.const import CONF_NAME as CONF_NAME
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_send as async_dispatcher_send
from homeassistant.util.decorator import Registry as Registry
from mysensors import BaseAsyncGateway as BaseAsyncGateway, Message as Message
from mysensors.sensor import ChildSensor as ChildSensor
from typing import Any, Callable

_LOGGER: Any
SCHEMAS: Any

def on_unload(hass: HomeAssistant, gateway_id: GatewayId, fnct: Callable) -> None: ...
def discover_mysensors_platform(hass: HomeAssistant, gateway_id: GatewayId, platform: str, new_devices: list[DevId]) -> None: ...
def default_schema(gateway: BaseAsyncGateway, child: ChildSensor, value_type_name: ValueType) -> vol.Schema: ...
def light_dimmer_schema(gateway: BaseAsyncGateway, child: ChildSensor, value_type_name: ValueType) -> vol.Schema: ...
def light_percentage_schema(gateway: BaseAsyncGateway, child: ChildSensor, value_type_name: ValueType) -> vol.Schema: ...
def light_rgb_schema(gateway: BaseAsyncGateway, child: ChildSensor, value_type_name: ValueType) -> vol.Schema: ...
def light_rgbw_schema(gateway: BaseAsyncGateway, child: ChildSensor, value_type_name: ValueType) -> vol.Schema: ...
def switch_ir_send_schema(gateway: BaseAsyncGateway, child: ChildSensor, value_type_name: ValueType) -> vol.Schema: ...
def get_child_schema(gateway: BaseAsyncGateway, child: ChildSensor, value_type_name: ValueType, schema: dict) -> vol.Schema: ...
def invalid_msg(gateway: BaseAsyncGateway, child: ChildSensor, value_type_name: ValueType) -> str: ...
def validate_set_msg(gateway_id: GatewayId, msg: Message) -> dict[str, list[DevId]]: ...
def validate_node(gateway: BaseAsyncGateway, node_id: int) -> bool: ...
def validate_child(gateway_id: GatewayId, gateway: BaseAsyncGateway, node_id: int, child: ChildSensor, value_type: Union[int, None] = ...) -> defaultdict[str, list[DevId]]: ...



import datetime
from .const import DATA_SUBSCRIBER as DATA_SUBSCRIBER, DOMAIN as DOMAIN
from .device_info import NestDeviceInfo as NestDeviceInfo
from google_nest_sdm.camera_traits import EventImageGenerator, RtspStream as RtspStream
from google_nest_sdm.device import Device as Device
from google_nest_sdm.event import ImageEventBase as ImageEventBase
from homeassistant.components.camera import Camera as Camera, SUPPORT_STREAM as SUPPORT_STREAM
from homeassistant.components.ffmpeg import async_get_image as async_get_image
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.exceptions import PlatformNotReady as PlatformNotReady
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.event import async_track_point_in_utc_time as async_track_point_in_utc_time
from homeassistant.util.dt import utcnow as utcnow
from typing import Any

_LOGGER: Any
STREAM_EXPIRATION_BUFFER: Any

async def async_setup_sdm_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class NestCamera(Camera):
    _device: Any
    _device_info: Any
    _stream: Any
    _stream_refresh_unsub: Any
    _event_id: Any
    _event_image_bytes: Any
    _event_image_cleanup_unsub: Any
    def __init__(self, device: Device) -> None: ...
    @property
    def should_poll(self) -> bool: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def name(self) -> Union[str, None]: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    @property
    def brand(self) -> Union[str, None]: ...
    @property
    def model(self) -> Union[str, None]: ...
    @property
    def supported_features(self) -> int: ...
    async def stream_source(self) -> Union[str, None]: ...
    def _schedule_stream_refresh(self) -> None: ...
    stream: Any
    async def _handle_stream_refresh(self, now: datetime.datetime) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_camera_image(self) -> Union[bytes, None]: ...
    async def _async_active_event_image(self) -> Union[bytes, None]: ...
    async def _async_fetch_active_event_image(self, trait: EventImageGenerator) -> Union[bytes, None]: ...
    def _schedule_event_image_cleanup(self, point_in_time: datetime.datetime) -> None: ...
    def _handle_event_image_cleanup(self, now: Any) -> None: ...



from . import GiosDataUpdateCoordinator as GiosDataUpdateCoordinator
from .const import ATTRIBUTION as ATTRIBUTION, ATTR_AQI as ATTR_AQI, ATTR_INDEX as ATTR_INDEX, ATTR_PM25 as ATTR_PM25, ATTR_STATION as ATTR_STATION, DEFAULT_NAME as DEFAULT_NAME, DOMAIN as DOMAIN, MANUFACTURER as MANUFACTURER, SENSOR_TYPES as SENSOR_TYPES
from .model import GiosSensorEntityDescription as GiosSensorEntityDescription
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION, ATTR_NAME as ATTR_NAME, CONF_NAME as CONF_NAME
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.entity_registry import async_get_registry as async_get_registry
from homeassistant.helpers.typing import StateType as StateType
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity
from typing import Any

_LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class GiosSensor(CoordinatorEntity, SensorEntity):
    coordinator: GiosDataUpdateCoordinator
    entity_description: GiosSensorEntityDescription
    _attr_device_info: Any
    _attr_icon: str
    _attr_name: Any
    _attr_unique_id: Any
    _attrs: Any
    def __init__(self, name: str, coordinator: GiosDataUpdateCoordinator, description: GiosSensorEntityDescription) -> None: ...
    @property
    def extra_state_attributes(self) -> dict[str, Any]: ...
    @property
    def state(self) -> StateType: ...

class GiosAqiSensor(GiosSensor):
    @property
    def state(self) -> StateType: ...
    @property
    def available(self) -> bool: ...



from homeassistant import core as core
from homeassistant.components.websocket_api.const import JSON_DUMP as JSON_DUMP
from homeassistant.const import ATTR_NOW as ATTR_NOW, EVENT_STATE_CHANGED as EVENT_STATE_CHANGED, EVENT_TIME_CHANGED as EVENT_TIME_CHANGED
from homeassistant.helpers.entityfilter import convert_include_exclude_filter as convert_include_exclude_filter
from homeassistant.helpers.json import JSONEncoder as JSONEncoder
from typing import Callable, TypeVar

CALLABLE_T = TypeVar('CALLABLE_T', bound=Callable)
BENCHMARKS: dict[str, Callable]

def run(args) -> None: ...
async def run_benchmark(bench) -> None: ...
def benchmark(func: CALLABLE_T) -> CALLABLE_T: ...
async def fire_events(hass): ...
async def fire_events_with_filter(hass): ...
async def time_changed_helper(hass): ...
async def state_changed_helper(hass): ...
async def state_changed_event_helper(hass): ...
async def state_changed_event_filter_helper(hass): ...
async def logbook_filtering_state(hass): ...
async def logbook_filtering_attributes(hass): ...
async def _logbook_filtering(hass, last_changed, last_updated): ...
async def filtering_entity_id(hass): ...
async def valid_entity_id(hass): ...
async def json_serialize_states(hass): ...
def _create_state_changed_event_from_old_new(entity_id, event_time_fired, old_state, new_state): ...



from . import RitualsDataUpdateCoordinator as RitualsDataUpdateCoordinator
from .const import COORDINATORS as COORDINATORS, DEVICES as DEVICES, DOMAIN as DOMAIN
from .entity import DiffuserEntity as DiffuserEntity
from homeassistant.components.number import NumberEntity as NumberEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from pyrituals import Diffuser as Diffuser
from typing import Any

MIN_PERFUME_AMOUNT: int
MAX_PERFUME_AMOUNT: int
PERFUME_AMOUNT_SUFFIX: str

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class DiffuserPerfumeAmount(DiffuserEntity, NumberEntity):
    _attr_icon: str
    _attr_max_value: Any
    _attr_min_value: Any
    def __init__(self, diffuser: Diffuser, coordinator: RitualsDataUpdateCoordinator) -> None: ...
    @property
    def value(self) -> int: ...
    async def async_set_value(self, value: float) -> None: ...



from . import KNXModule as KNXModule
from .const import DOMAIN as DOMAIN
from homeassistant.helpers.entity import Entity as Entity
from typing import Any
from xknx.devices import Device as XknxDevice

class KnxEntity(Entity):
    _attr_should_poll: bool
    _device: Any
    def __init__(self, device: XknxDevice) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def available(self) -> bool: ...
    async def async_update(self) -> None: ...
    async def after_update_callback(self, device: XknxDevice) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...



from typing import Any

LOGGER: Any
DOMAIN: str
CONF_ZONE_RUN_TIME: str
DATA_CONTROLLER: str
DATA_COORDINATOR: str
DATA_PROGRAMS: str
DATA_PROVISION_SETTINGS: str
DATA_RESTRICTIONS_CURRENT: str
DATA_RESTRICTIONS_UNIVERSAL: str
DATA_ZONES: str
DEFAULT_PORT: int
DEFAULT_ZONE_RUN: Any



from . import DOMAIN as DOMAIN
from homeassistant.components.device_automation import toggle_entity as toggle_entity
from homeassistant.const import CONF_DOMAIN as CONF_DOMAIN
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.condition import ConditionCheckerType as ConditionCheckerType
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

CONDITION_SCHEMA: Any

def async_condition_from_config(config: ConfigType, config_validation: bool) -> ConditionCheckerType: ...
async def async_get_conditions(hass: HomeAssistant, device_id: str) -> list[dict[str, str]]: ...
async def async_get_condition_capabilities(hass: HomeAssistant, config: dict) -> dict: ...



from .devolo_device import DevoloDeviceEntity as DevoloDeviceEntity
from devolo_home_control_api.devices.zwave import Zwave as Zwave
from devolo_home_control_api.homecontrol import HomeControl as HomeControl
from typing import Any

class DevoloMultiLevelSwitchDeviceEntity(DevoloDeviceEntity):
    _multi_level_switch_property: Any
    _value: Any
    def __init__(self, homecontrol: HomeControl, device_instance: Zwave, element_uid: str) -> None: ...



from .const import CONF_DSMR_VERSION as CONF_DSMR_VERSION, CONF_PRECISION as CONF_PRECISION, CONF_RECONNECT_INTERVAL as CONF_RECONNECT_INTERVAL, CONF_SERIAL_ID as CONF_SERIAL_ID, CONF_SERIAL_ID_GAS as CONF_SERIAL_ID_GAS, CONF_TIME_BETWEEN_UPDATE as CONF_TIME_BETWEEN_UPDATE, DATA_TASK as DATA_TASK, DEFAULT_DSMR_VERSION as DEFAULT_DSMR_VERSION, DEFAULT_PORT as DEFAULT_PORT, DEFAULT_PRECISION as DEFAULT_PRECISION, DEFAULT_RECONNECT_INTERVAL as DEFAULT_RECONNECT_INTERVAL, DEFAULT_TIME_BETWEEN_UPDATE as DEFAULT_TIME_BETWEEN_UPDATE, DEVICE_NAME_ENERGY as DEVICE_NAME_ENERGY, DEVICE_NAME_GAS as DEVICE_NAME_GAS, DOMAIN as DOMAIN, LOGGER as LOGGER, SENSORS as SENSORS
from .models import DSMRSensorEntityDescription as DSMRSensorEntityDescription
from dsmr_parser.objects import DSMRObject as DSMRObject
from homeassistant.components.sensor import PLATFORM_SCHEMA as PLATFORM_SCHEMA, SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry, SOURCE_IMPORT as SOURCE_IMPORT
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PORT as CONF_PORT, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP
from homeassistant.core import CoreState as CoreState, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType, StateType as StateType
from homeassistant.util import Throttle as Throttle
from typing import Any

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[dict[str, Any], None] = ...) -> None: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class DSMREntity(SensorEntity):
    entity_description: DSMRSensorEntityDescription
    _attr_should_poll: bool
    _entry: Any
    telegram: Any
    _attr_device_info: Any
    _attr_unique_id: Any
    def __init__(self, entity_description: DSMRSensorEntityDescription, entry: ConfigEntry) -> None: ...
    def update_data(self, telegram: dict[str, DSMRObject]) -> None: ...
    def get_dsmr_object_attr(self, attribute: str) -> Union[str, None]: ...
    @property
    def state(self) -> StateType: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...
    @staticmethod
    def translate_tariff(value: str, dsmr_version: str) -> Union[str, None]: ...
